# copyright ############################### #
# This file is part of the Xcoll Package.   #
# Copyright (c) CERN, 2025.                 #
# ######################################### #

from ...xoconstants import Constants, constant


class FlukaMasses(Constants):
    _category_ = "fluka_mass"
    _plural_   = "fluka_masses"
    _c_prefix_ = "XC_FLUKA"

    ELECTRON_MASS_EV = constant(      510999.0600, "Electron mass in eV as used in FLUKA.",  pdg_id=11)    # best known value:     510998.95069(16) eV
    MUON_MASS_EV     = constant(   105658389.0000, "Muon mass in eV as used in FLUKA.",      pdg_id=13)    # best known value:     105658375.5(23) eV
    PION_MASS_EV     = constant(   139569950.0000, "Pion mass in eV as used in FLUKA.",      pdg_id=211)
    KAON_MASS_EV     = constant(   493646000.0000, "Kaon mass in eV as used in FLUKA.",      pdg_id=321)
    PROTON_MASS_EV   = constant(   938272310.0000, "Proton mass in eV as used in FLUKA.",    pdg_id=2212)  # best known value:     938272088.15(29) eV
    DEUTERON_MASS_EV = constant(  1875613390.0000, "Deuteron mass in eV as used in FLUKA.",  pdg_id=1000010020)
    TRITON_MASS_EV   = constant(  2808921774.1526, "Triton mass in eV as used in FLUKA.",    pdg_id=1000010030)

    He3_MASS_EV      = constant(  2808392236.6048, "He3 mass in eV as used in FLUKA.",   pdg_id=1000020030)
    He4_MASS_EV      = constant(  3727380256.9289, "He4 mass in eV as used in FLUKA.",   pdg_id=1000020040)
    He5_MASS_EV      = constant(  4667835926.6967, "He5 mass in eV as used in FLUKA.",   pdg_id=1000020050)
    He6_MASS_EV      = constant(  5605538106.5358, "He6 mass in eV as used in FLUKA.",   pdg_id=1000020060)
    He7_MASS_EV      = constant(  6545548646.3151, "He7 mass in eV as used in FLUKA.",   pdg_id=1000020070)
    He8_MASS_EV      = constant(  7482530706.1729, "He8 mass in eV as used in FLUKA.",   pdg_id=1000020080)

    Li6_MASS_EV      = constant(  5601519470.4097, "Li6 mass in eV as used in FLUKA.",   pdg_id=1000030060)
    Li7_MASS_EV      = constant(  6533835190.3885, "Li7 mass in eV as used in FLUKA.",   pdg_id=1000030070)
    Li8_MASS_EV      = constant(  7471367020.2320, "Li8 mass in eV as used in FLUKA.",   pdg_id=1000030080)
    Li9_MASS_EV      = constant(  8406870100.1281, "Li9 mass in eV as used in FLUKA.",   pdg_id=1000030090)
    Li10_MASS_EV     = constant(  9346855049.9081, "Li10 mass in eV as used in FLUKA.",  pdg_id=1000030100)
    Li11_MASS_EV     = constant( 10285692859.7178, "Li11 mass in eV as used in FLUKA.",  pdg_id=1000030110)

    Be7_MASS_EV      = constant(  6534186187.0551, "Be7 mass in eV as used in FLUKA.",   pdg_id=1000040070)
    Be8_MASS_EV      = constant(  7454852657.3357, "Be8 mass in eV as used in FLUKA.",   pdg_id=1000040080)
    Be9_MASS_EV      = constant(  8392753017.1697, "Be9 mass in eV as used in FLUKA.",   pdg_id=1000040090)
    Be10_MASS_EV     = constant(  9325506337.1371, "Be10 mass in eV as used in FLUKA.",  pdg_id=1000040100)
    Be11_MASS_EV     = constant( 10264568076.9410, "Be11 mass in eV as used in FLUKA.",  pdg_id=1000040110)
    Be12_MASS_EV     = constant( 11200964756.8139, "Be12 mass in eV as used in FLUKA.",  pdg_id=1000040120)
    Be13_MASS_EV     = constant( 12142541006.5527, "Be13 mass in eV as used in FLUKA.",  pdg_id=1000040130)
    Be14_MASS_EV     = constant( 13078759286.4303, "Be14 mass in eV as used in FLUKA.",  pdg_id=1000040140)

    B8_MASS_EV       = constant(  7472321245.2018, "B8 mass in eV as used in FLUKA.",    pdg_id=1000050080)
    B9_MASS_EV       = constant(  8393310365.4740, "B9 mass in eV as used in FLUKA.",    pdg_id=1000050090)
    B10_MASS_EV      = constant(  9324439705.4834, "B10 mass in eV as used in FLUKA.",   pdg_id=1000050100)
    B11_MASS_EV      = constant( 10252551235.5711, "B11 mass in eV as used in FLUKA.",   pdg_id=1000050110)
    B12_MASS_EV      = constant( 11188746425.4493, "B12 mass in eV as used in FLUKA.",   pdg_id=1000050120)
    B13_MASS_EV      = constant( 12123434145.3666, "B13 mass in eV as used in FLUKA.",   pdg_id=1000050130)
    B14_MASS_EV      = constant( 13062029875.1825, "B14 mass in eV as used in FLUKA.",   pdg_id=1000050140)
    B15_MASS_EV      = constant( 13998827395.0451, "B15 mass in eV as used in FLUKA.",   pdg_id=1000050150)
    B16_MASS_EV      = constant( 14938494194.8333, "B16 mass in eV as used in FLUKA.",   pdg_id=1000050160)
    B17_MASS_EV      = constant( 15876565424.6629, "B17 mass in eV as used in FLUKA.",   pdg_id=1000050170)
    B18_MASS_EV      = constant( 16816666234.4399, "B18 mass in eV as used in FLUKA.",   pdg_id=1000050180)
    B19_MASS_EV      = constant( 17753646308.4133, "B19 mass in eV as used in FLUKA.",   pdg_id=1000050190)
    B20_MASS_EV      = constant( 18695610342.2641, "B20 mass in eV as used in FLUKA.",   pdg_id=1000050200)
    B21_MASS_EV      = constant( 19627796224.8218, "B21 mass in eV as used in FLUKA.",   pdg_id=1000050210)
    B22_MASS_EV      = constant( 20561795084.8209, "B22 mass in eV as used in FLUKA.",   pdg_id=1000050220)
    B23_MASS_EV      = constant( 21491344416.3474, "B23 mass in eV as used in FLUKA.",   pdg_id=1000050230)
    B24_MASS_EV      = constant( 22425823568.7792, "B24 mass in eV as used in FLUKA.",   pdg_id=1000050240)
    B25_MASS_EV      = constant( 23361517466.3034, "B25 mass in eV as used in FLUKA.",   pdg_id=1000050250)

    C9_MASS_EV       = constant(  8409297942.4853, "C9 mass in eV as used in FLUKA.",    pdg_id=1000060090)
    C10_MASS_EV      = constant(  9327576872.8277, "C10 mass in eV as used in FLUKA.",   pdg_id=1000060100)
    C11_MASS_EV      = constant( 10254022852.9586, "C11 mass in eV as used in FLUKA.",   pdg_id=1000060110)
    C12_MASS_EV      = constant( 11174866883.2345, "C12 mass in eV as used in FLUKA.",   pdg_id=1000060120)
    C13_MASS_EV      = constant( 12109486203.1536, "C13 mass in eV as used in FLUKA.",   pdg_id=1000060130)
    C14_MASS_EV      = constant( 13040875423.1563, "C14 mass in eV as used in FLUKA.",   pdg_id=1000060140)
    C15_MASS_EV      = constant( 13979223022.9787, "C15 mass in eV as used in FLUKA.",   pdg_id=1000060150)
    C16_MASS_EV      = constant( 14914538302.8797, "C16 mass in eV as used in FLUKA.",   pdg_id=1000060160)
    C17_MASS_EV      = constant( 15853375102.6894, "C17 mass in eV as used in FLUKA.",   pdg_id=1000060170)
    C18_MASS_EV      = constant( 16788757102.5887, "C18 mass in eV as used in FLUKA.",   pdg_id=1000060180)
    C30_MASS_EV      = constant( 28026329089.7061, "C30 mass in eV as used in FLUKA.",   pdg_id=1000060300)

    N12_MASS_EV      = constant( 11191694455.9209, "N12 mass in eV as used in FLUKA.",   pdg_id=1000070120)
    N13_MASS_EV      = constant( 12111196196.2317, "N13 mass in eV as used in FLUKA.",   pdg_id=1000070130)
    N14_MASS_EV      = constant( 13040208386.2960, "N14 mass in eV as used in FLUKA.",   pdg_id=1000070140)
    N15_MASS_EV      = constant( 13968940806.3676, "N15 mass in eV as used in FLUKA.",   pdg_id=1000070150)
    N16_MASS_EV      = constant( 14906015646.2229, "N16 mass in eV as used in FLUKA.",   pdg_id=1000070160)
    N17_MASS_EV      = constant( 15839698756.1662, "N17 mass in eV as used in FLUKA.",   pdg_id=1000070170)
    N18_MASS_EV      = constant( 16776439386.0303, "N18 mass in eV as used in FLUKA.",   pdg_id=1000070180)
    N19_MASS_EV      = constant( 17710677005.9592, "N19 mass in eV as used in FLUKA.",   pdg_id=1000070190)
    N20_MASS_EV      = constant( 18648077455.8061, "N20 mass in eV as used in FLUKA.",   pdg_id=1000070200)
    N21_MASS_EV      = constant( 19583037215.7163, "N21 mass in eV as used in FLUKA.",   pdg_id=1000070210)

    O13_MASS_EV      = constant( 12128451020.5484, "O13 mass in eV as used in FLUKA.",   pdg_id=1000080130)
    O14_MASS_EV      = constant( 13044841910.9398, "O14 mass in eV as used in FLUKA.",   pdg_id=1000080140)
    O15_MASS_EV      = constant( 13971184421.0733, "O15 mass in eV as used in FLUKA.",   pdg_id=1000080150)
    O16_MASS_EV      = constant( 14895086191.2700, "O16 mass in eV as used in FLUKA.",   pdg_id=1000080160)
    O17_MASS_EV      = constant( 15830508491.1682, "O17 mass in eV as used in FLUKA.",   pdg_id=1000080170)
    O18_MASS_EV      = constant( 16762029651.1675, "O18 mass in eV as used in FLUKA.",   pdg_id=1000080180)
    O19_MASS_EV      = constant( 17697638381.0609, "O19 mass in eV as used in FLUKA.",   pdg_id=1000080190)
    O20_MASS_EV      = constant( 18629597381.0489, "O20 mass in eV as used in FLUKA.",   pdg_id=1000080200)
    O21_MASS_EV      = constant( 19565356500.9384, "O21 mass in eV as used in FLUKA.",   pdg_id=1000080210)
    O22_MASS_EV      = constant( 20498073470.9067, "O22 mass in eV as used in FLUKA.",   pdg_id=1000080220)

    F17_MASS_EV      = constant( 15832758902.9589, "F17 mass in eV as used in FLUKA.",   pdg_id=1000090170)
    F18_MASS_EV      = constant( 16763174962.9869, "F18 mass in eV as used in FLUKA.",   pdg_id=1000090180)
    F19_MASS_EV      = constant( 17692308413.0480, "F19 mass in eV as used in FLUKA.",   pdg_id=1000090190)
    F20_MASS_EV      = constant( 18625272733.0099, "F20 mass in eV as used in FLUKA.",   pdg_id=1000090200)
    F21_MASS_EV      = constant( 19556736843.0107, "F21 mass in eV as used in FLUKA.",   pdg_id=1000090210)
    F22_MASS_EV      = constant( 20491072592.9371, "F22 mass in eV as used in FLUKA.",   pdg_id=1000090220)
    F23_MASS_EV      = constant( 21423102682.9232, "F23 mass in eV as used in FLUKA.",   pdg_id=1000090230)
    F24_MASS_EV      = constant( 22358811992.8140, "F24 mass in eV as used in FLUKA.",   pdg_id=1000090240)
    F25_MASS_EV      = constant( 23294028222.7175, "F25 mass in eV as used in FLUKA.",   pdg_id=1000090250)

    Ne18_MASS_EV     = constant( 16767110436.8600, "Ne18 mass in eV as used in FLUKA.",  pdg_id=1000100180)
    Ne19_MASS_EV     = constant( 17695036666.9525, "Ne19 mass in eV as used in FLUKA.",  pdg_id=1000100190)
    Ne20_MASS_EV     = constant( 18617738027.1804, "Ne20 mass in eV as used in FLUKA.",  pdg_id=1000100200)
    Ne21_MASS_EV     = constant( 19550542547.1464, "Ne21 mass in eV as used in FLUKA.",  pdg_id=1000100210)
    Ne22_MASS_EV     = constant( 20479744147.2058, "Ne22 mass in eV as used in FLUKA.",  pdg_id=1000100220)
    Ne23_MASS_EV     = constant( 21414109157.1314, "Ne23 mass in eV as used in FLUKA.",  pdg_id=1000100230)
    Ne24_MASS_EV     = constant( 22344809697.1520, "Ne24 mass in eV as used in FLUKA.",  pdg_id=1000100240)
    Ne25_MASS_EV     = constant( 23280192787.0512, "Ne25 mass in eV as used in FLUKA.",  pdg_id=1000100250)
    Ne26_MASS_EV     = constant( 24214175696.9867, "Ne26 mass in eV as used in FLUKA.",  pdg_id=1000100260)
    Ne27_MASS_EV     = constant( 25152333756.8140, "Ne27 mass in eV as used in FLUKA.",  pdg_id=1000100270)

    Na19_MASS_EV     = constant( 17705704117.4861, "Na19 mass in eV as used in FLUKA.",  pdg_id=1000110190)
    Na20_MASS_EV     = constant( 18631114797.6438, "Na20 mass in eV as used in FLUKA.",  pdg_id=1000110200)
    Na21_MASS_EV     = constant( 19553579777.8778, "Na21 mass in eV as used in FLUKA.",  pdg_id=1000110210)
    Na22_MASS_EV     = constant( 20482076227.9555, "Na22 mass in eV as used in FLUKA.",  pdg_id=1000110220)
    Na23_MASS_EV     = constant( 21409223268.0681, "Na23 mass in eV as used in FLUKA.",  pdg_id=1000110230)
    Na24_MASS_EV     = constant( 22341829488.0393, "Na24 mass in eV as used in FLUKA.",  pdg_id=1000110240)
    Na25_MASS_EV     = constant( 23272383918.0637, "Na25 mass in eV as used in FLUKA.",  pdg_id=1000110250)
    Na26_MASS_EV     = constant( 24206333238.0001, "Na26 mass in eV as used in FLUKA.",  pdg_id=1000110260)
    Na27_MASS_EV     = constant( 25139149127.9658, "Na27 mass in eV as used in FLUKA.",  pdg_id=1000110270)
    Na28_MASS_EV     = constant( 26075190707.8480, "Na28 mass in eV as used in FLUKA.",  pdg_id=1000110280)
    Na29_MASS_EV     = constant( 27010337597.7533, "Na29 mass in eV as used in FLUKA.",  pdg_id=1000110290)
    Na30_MASS_EV     = constant( 27947807517.5985, "Na30 mass in eV as used in FLUKA.",  pdg_id=1000110300)
    Na31_MASS_EV     = constant( 28883371167.4930, "Na31 mass in eV as used in FLUKA.",  pdg_id=1000110310)

    Mg20_MASS_EV     = constant( 18641330379.4529, "Mg20 mass in eV as used in FLUKA.",  pdg_id=1000120200)
    Mg21_MASS_EV     = constant( 19566165889.6254, "Mg21 mass in eV as used in FLUKA.",  pdg_id=1000120210)
    Mg22_MASS_EV     = constant( 20486351679.9185, "Mg22 mass in eV as used in FLUKA.",  pdg_id=1000120220)
    Mg23_MASS_EV     = constant( 21412770100.0500, "Mg23 mass in eV as used in FLUKA.",  pdg_id=1000120230)
    Mg24_MASS_EV     = constant( 22335803710.2693, "Mg24 mass in eV as used in FLUKA.",  pdg_id=1000120240)
    Mg25_MASS_EV     = constant( 23268038730.2501, "Mg25 mass in eV as used in FLUKA.",  pdg_id=1000120250)
    Mg26_MASS_EV     = constant( 24196511250.3284, "Mg26 mass in eV as used in FLUKA.",  pdg_id=1000120260)
    Mg27_MASS_EV     = constant( 25129633570.2862, "Mg27 mass in eV as used in FLUKA.",  pdg_id=1000120270)
    Mg28_MASS_EV     = constant( 26060695590.2974, "Mg28 mass in eV as used in FLUKA.",  pdg_id=1000120280)
    Mg29_MASS_EV     = constant( 26996547500.1845, "Mg29 mass in eV as used in FLUKA.",  pdg_id=1000120290)
    Mg30_MASS_EV     = constant( 27929820780.1384, "Mg30 mass in eV as used in FLUKA.",  pdg_id=1000120300)
    Mg31_MASS_EV     = constant( 28866982189.9915, "Mg31 mass in eV as used in FLUKA.",  pdg_id=1000120310)
    Mg32_MASS_EV     = constant( 29800895989.9288, "Mg32 mass in eV as used in FLUKA.",  pdg_id=1000120320)

    Al23_MASS_EV     = constant( 21424500177.2724, "Al23 mass in eV as used in FLUKA.",  pdg_id=1000130230)
    Al24_MASS_EV     = constant( 22349172137.4492, "Al24 mass in eV as used in FLUKA.",  pdg_id=1000130240)
    Al25_MASS_EV     = constant( 23271805727.6788, "Al25 mass in eV as used in FLUKA.",  pdg_id=1000130250)
    Al26_MASS_EV     = constant( 24200005587.7642, "Al26 mass in eV as used in FLUKA.",  pdg_id=1000130260)
    Al27_MASS_EV     = constant( 25126513317.8934, "Al27 mass in eV as used in FLUKA.",  pdg_id=1000130270)
    Al28_MASS_EV     = constant( 26058353937.8845, "Al28 mass in eV as used in FLUKA.",  pdg_id=1000130280)
    Al29_MASS_EV     = constant( 26988483367.9198, "Al29 mass in eV as used in FLUKA.",  pdg_id=1000130290)
    Al30_MASS_EV     = constant( 27922320787.8591, "Al30 mass in eV as used in FLUKA.",  pdg_id=1000130300)
    Al31_MASS_EV     = constant( 28854733297.8353, "Al31 mass in eV as used in FLUKA.",  pdg_id=1000130310)
    Al32_MASS_EV     = constant( 29790119647.7345, "Al32 mass in eV as used in FLUKA.",  pdg_id=1000130320)

    Si25_MASS_EV     = constant( 23284037184.3215, "Si25 mass in eV as used in FLUKA.",  pdg_id=1000140250)
    Si26_MASS_EV     = constant( 24204561464.6058, "Si26 mass in eV as used in FLUKA.",  pdg_id=1000140260)
    Si27_MASS_EV     = constant( 25130815494.7416, "Si27 mass in eV as used in FLUKA.",  pdg_id=1000140270)
    Si28_MASS_EV     = constant( 26053202014.9776, "Si28 mass in eV as used in FLUKA.",  pdg_id=1000140280)
    Si29_MASS_EV     = constant( 26984294034.9880, "Si29 mass in eV as used in FLUKA.",  pdg_id=1000140290)
    Si30_MASS_EV     = constant( 27913250555.0538, "Si30 mass in eV as used in FLUKA.",  pdg_id=1000140300)
    Si31_MASS_EV     = constant( 28846228775.0153, "Si31 mass in eV as used in FLUKA.",  pdg_id=1000140310)
    Si32_MASS_EV     = constant( 29776591195.0447, "Si32 mass in eV as used in FLUKA.",  pdg_id=1000140320)
    Si33_MASS_EV     = constant( 30711674014.9517, "Si33 mass in eV as used in FLUKA.",  pdg_id=1000140330)
    Si34_MASS_EV     = constant( 31643704144.9378, "Si34 mass in eV as used in FLUKA.",  pdg_id=1000140340)
    Si35_MASS_EV     = constant( 32580795234.7928, "Si35 mass in eV as used in FLUKA.",  pdg_id=1000140350)

    P27_MASS_EV      = constant( 25141937994.6439, "P27 mass in eV as used in FLUKA.",   pdg_id=1000150270)
    P28_MASS_EV      = constant( 26067024104.8099, "P28 mass in eV as used in FLUKA.",   pdg_id=1000150280)
    P29_MASS_EV      = constant( 26988727585.0637, "P29 mass in eV as used in FLUKA.",   pdg_id=1000150290)
    P30_MASS_EV      = constant( 27916973245.1478, "P30 mass in eV as used in FLUKA.",   pdg_id=1000150300)
    P31_MASS_EV      = constant( 28844227175.2577, "P31 mass in eV as used in FLUKA.",   pdg_id=1000150310)
    P32_MASS_EV      = constant( 29775857195.2542, "P32 mass in eV as used in FLUKA.",   pdg_id=1000150320)
    P33_MASS_EV      = constant( 30705319135.3069, "P33 mass in eV as used in FLUKA.",   pdg_id=1000150330)
    P34_MASS_EV      = constant( 31638593515.2608, "P34 mass in eV as used in FLUKA.",   pdg_id=1000150340)
    P35_MASS_EV      = constant( 32569787865.2685, "P35 mass in eV as used in FLUKA.",   pdg_id=1000150350)
    P36_MASS_EV      = constant( 33505888995.1491, "P36 mass in eV as used in FLUKA.",   pdg_id=1000150360)
    P37_MASS_EV      = constant( 34438639385.1166, "P37 mass in eV as used in FLUKA.",   pdg_id=1000150370)
    P38_MASS_EV      = constant( 35374662334.9992, "P38 mass in eV as used in FLUKA.",   pdg_id=1000150380)
    P39_MASS_EV      = constant( 36307973054.9522, "P39 mass in eV as used in FLUKA.",   pdg_id=1000150390)

    S29_MASS_EV      = constant( 27002011261.7761, "S29 mass in eV as used in FLUKA.",   pdg_id=1000160290)
    S30_MASS_EV      = constant( 27922601602.0587, "S30 mass in eV as used in FLUKA.",   pdg_id=1000160300)
    S31_MASS_EV      = constant( 28849113842.1878, "S31 mass in eV as used in FLUKA.",   pdg_id=1000160310)
    S32_MASS_EV      = constant( 29773637162.3685, "S32 mass in eV as used in FLUKA.",   pdg_id=1000160320)
    S33_MASS_EV      = constant( 30704561182.3832, "S33 mass in eV as used in FLUKA.",   pdg_id=1000160330)
    S34_MASS_EV      = constant( 31632709902.4699, "S34 mass in eV as used in FLUKA.",   pdg_id=1000160340)
    S35_MASS_EV      = constant( 32565289722.4418, "S35 mass in eV as used in FLUKA.",   pdg_id=1000160350)
    S36_MASS_EV      = constant( 33494966332.4889, "S36 mass in eV as used in FLUKA.",   pdg_id=1000160360)
    S37_MASS_EV      = constant( 34430228442.3913, "S37 mass in eV as used in FLUKA.",   pdg_id=1000160370)
    S38_MASS_EV      = constant( 35361757822.3904, "S38 mass in eV as used in FLUKA.",   pdg_id=1000160380)
    S39_MASS_EV      = constant( 36296951962.2945, "S39 mass in eV as used in FLUKA.",   pdg_id=1000160390)
    S40_MASS_EV      = constant( 37228758112.2864, "S40 mass in eV as used in FLUKA.",   pdg_id=1000160400)
    S41_MASS_EV      = constant( 38164500032.1763, "S41 mass in eV as used in FLUKA.",   pdg_id=1000160410)

    Cl32_MASS_EV     = constant( 29785812989.4660, "Cl32 mass in eV as used in FLUKA.",  pdg_id=1000170320)
    Cl33_MASS_EV     = constant( 30709634529.6648, "Cl33 mass in eV as used in FLUKA.",  pdg_id=1000170330)
    Cl34_MASS_EV     = constant( 31637692779.7539, "Cl34 mass in eV as used in FLUKA.",  pdg_id=1000170340)
    Cl35_MASS_EV     = constant( 32564613219.8724, "Cl35 mass in eV as used in FLUKA.",  pdg_id=1000170350)
    Cl36_MASS_EV     = constant( 33495599129.8856, "Cl36 mass in eV as used in FLUKA.",  pdg_id=1000170360)
    Cl37_MASS_EV     = constant( 34424853859.9436, "Cl37 mass in eV as used in FLUKA.",  pdg_id=1000170370)
    Cl38_MASS_EV     = constant( 35358311669.8927, "Cl38 mass in eV as used in FLUKA.",  pdg_id=1000170380)
    Cl39_MASS_EV     = constant( 36289804179.8928, "Cl39 mass in eV as used in FLUKA.",  pdg_id=1000170390)
    Cl40_MASS_EV     = constant( 37223540589.8347, "Cl40 mass in eV as used in FLUKA.",  pdg_id=1000170400)
    Cl41_MASS_EV     = constant( 38155253479.8290, "Cl41 mass in eV as used in FLUKA.",  pdg_id=1000170410)
    Cl42_MASS_EV     = constant( 39089099649.7681, "Cl42 mass in eV as used in FLUKA.",  pdg_id=1000170420)
    Cl43_MASS_EV     = constant( 40021551859.7432, "Cl43 mass in eV as used in FLUKA.",  pdg_id=1000170430)

    Ar34_MASS_EV     = constant( 31643244900.7387, "Ar34 mass in eV as used in FLUKA.",  pdg_id=1000180340)
    Ar35_MASS_EV     = constant( 32570069270.8597, "Ar35 mass in eV as used in FLUKA.",  pdg_id=1000180350)
    Ar36_MASS_EV     = constant( 33494381341.0459, "Ar36 mass in eV as used in FLUKA.",  pdg_id=1000180360)
    Ar37_MASS_EV     = constant( 34425158161.0645, "Ar37 mass in eV as used in FLUKA.",  pdg_id=1000180370)
    Ar38_MASS_EV     = constant( 35352885661.1621, "Ar38 mass in eV as used in FLUKA.",  pdg_id=1000180380)
    Ar39_MASS_EV     = constant( 36285852981.1239, "Ar39 mass in eV as used in FLUKA.",  pdg_id=1000180390)
    Ar40_MASS_EV     = constant( 37215549251.1705, "Ar40 mass in eV as used in FLUKA.",  pdg_id=1000180400)
    Ar41_MASS_EV     = constant( 38149016101.1194, "Ar41 mass in eV as used in FLUKA.",  pdg_id=1000180410)
    Ar42_MASS_EV     = constant( 39079155651.1545, "Ar42 mass in eV as used in FLUKA.",  pdg_id=1000180420)
    Ar43_MASS_EV     = constant( 40013094441.0911, "Ar43 mass in eV as used in FLUKA.",  pdg_id=1000180430)
    Ar44_MASS_EV     = constant( 40944304311.0985, "Ar44 mass in eV as used in FLUKA.",  pdg_id=1000180440)
    Ar45_MASS_EV     = constant( 41878341291.0326, "Ar45 mass in eV as used in FLUKA.",  pdg_id=1000180450)
    Ar46_MASS_EV     = constant( 42809834231.0327, "Ar46 mass in eV as used in FLUKA.",  pdg_id=1000180460)

    K37_MASS_EV      = constant( 34430797839.0035, "K37 mass in eV as used in FLUKA.",   pdg_id=1000190370)
    K38_MASS_EV      = constant( 35358289719.1072, "K38 mass in eV as used in FLUKA.",   pdg_id=1000190380)
    K39_MASS_EV      = constant( 36284778979.2369, "K39 mass in eV as used in FLUKA.",   pdg_id=1000190390)
    K40_MASS_EV      = constant( 37216545099.2299, "K40 mass in eV as used in FLUKA.",   pdg_id=1000190400)
    K41_MASS_EV      = constant( 38146015519.2823, "K41 mass in eV as used in FLUKA.",   pdg_id=1000190410)
    K42_MASS_EV      = constant( 39078047439.2684, "K42 mass in eV as used in FLUKA.",   pdg_id=1000190420)
    K43_MASS_EV      = constant( 40007969189.3091, "K43 mass in eV as used in FLUKA.",   pdg_id=1000190430)
    K44_MASS_EV      = constant( 40940247179.2888, "K44 mass in eV as used in FLUKA.",   pdg_id=1000190440)
    K45_MASS_EV      = constant( 41870943619.3095, "K45 mass in eV as used in FLUKA.",   pdg_id=1000190450)
    K46_MASS_EV      = constant( 42803627039.2787, "K46 mass in eV as used in FLUKA.",   pdg_id=1000190460)
    K47_MASS_EV      = constant( 43734842569.2859, "K47 mass in eV as used in FLUKA.",   pdg_id=1000190470)

    Ca39_MASS_EV     = constant( 36290800617.2551, "Ca39 mass in eV as used in FLUKA.",  pdg_id=1000200390)
    Ca40_MASS_EV     = constant( 37214725127.4512, "Ca40 mass in eV as used in FLUKA.",  pdg_id=1000200400)
    Ca41_MASS_EV     = constant( 38145928037.4588, "Ca41 mass in eV as used in FLUKA.",  pdg_id=1000200410)
    Ca42_MASS_EV     = constant( 39074013057.5471, "Ca42 mass in eV as used in FLUKA.",  pdg_id=1000200420)
    Ca43_MASS_EV     = constant( 40005645767.5435, "Ca43 mass in eV as used in FLUKA.",  pdg_id=1000200430)
    Ca44_MASS_EV     = constant( 40934079347.6229, "Ca44 mass in eV as used in FLUKA.",  pdg_id=1000200440)
    Ca45_MASS_EV     = constant( 41866230267.6058, "Ca45 mass in eV as used in FLUKA.",  pdg_id=1000200450)
    Ca46_MASS_EV     = constant( 42795402147.6660, "Ca46 mass in eV as used in FLUKA.",  pdg_id=1000200460)
    Ca47_MASS_EV     = constant( 43727691777.6454, "Ca47 mass in eV as used in FLUKA.",  pdg_id=1000200470)
    Ca48_MASS_EV     = constant( 44657310977.6940, "Ca48 mass in eV as used in FLUKA.",  pdg_id=1000200480)

    Sc41_MASS_EV     = constant( 38151914628.6004, "Sc41 mass in eV as used in FLUKA.",  pdg_id=1000210410)
    Sc42_MASS_EV     = constant( 39079930238.6905, "Sc42 mass in eV as used in FLUKA.",  pdg_id=1000210420)
    Sc43_MASS_EV     = constant( 40007357878.7959, "Sc43 mass in eV as used in FLUKA.",  pdg_id=1000210430)
    Sc44_MASS_EV     = constant( 40937223998.8381, "Sc44 mass in eV as used in FLUKA.",  pdg_id=1000210440)
    Sc45_MASS_EV     = constant( 41865464728.9224, "Sc45 mass in eV as used in FLUKA.",  pdg_id=1000210450)
    Sc46_MASS_EV     = constant( 42796269748.9403, "Sc46 mass in eV as used in FLUKA.",  pdg_id=1000210460)
    Sc47_MASS_EV     = constant( 43725191059.0069, "Sc47 mass in eV as used in FLUKA.",  pdg_id=1000210470)
    Sc48_MASS_EV     = constant( 44656524149.0111, "Sc48 mass in eV as used in FLUKA.",  pdg_id=1000210480)
    Sc49_MASS_EV     = constant( 45585959079.0645, "Sc49 mass in eV as used in FLUKA.",  pdg_id=1000210490)
    Sc50_MASS_EV     = constant( 46519468119.0123, "Sc50 mass in eV as used in FLUKA.",  pdg_id=1000210500)
    Sc51_MASS_EV     = constant( 47452281138.9781, "Sc51 mass in eV as used in FLUKA.",  pdg_id=1000210510)

    Ti42_MASS_EV     = constant( 39086421665.8838, "Ti42 mass in eV as used in FLUKA.",  pdg_id=1000220420)
    Ti43_MASS_EV     = constant( 40013716565.9926, "Ti43 mass in eV as used in FLUKA.",  pdg_id=1000220430)
    Ti44_MASS_EV     = constant( 40936982876.2058, "Ti44 mass in eV as used in FLUKA.",  pdg_id=1000220440)
    Ti45_MASS_EV     = constant( 41867018666.2436, "Ti45 mass in eV as used in FLUKA.",  pdg_id=1000220450)
    Ti46_MASS_EV     = constant( 42793394486.3763, "Ti46 mass in eV as used in FLUKA.",  pdg_id=1000220460)
    Ti47_MASS_EV     = constant( 43724082406.3972, "Ti47 mass in eV as used in FLUKA.",  pdg_id=1000220470)
    Ti48_MASS_EV     = constant( 44652021436.4893, "Ti48 mass in eV as used in FLUKA.",  pdg_id=1000220480)
    Ti49_MASS_EV     = constant( 45583444746.4911, "Ti49 mass in eV as used in FLUKA.",  pdg_id=1000220490)
    Ti50_MASS_EV     = constant( 46512071266.5655, "Ti50 mass in eV as used in FLUKA.",  pdg_id=1000220500)
    Ti51_MASS_EV     = constant( 47445264586.5214, "Ti51 mass in eV as used in FLUKA.",  pdg_id=1000220510)
    Ti52_MASS_EV     = constant( 48377021646.5146, "Ti52 mass in eV as used in FLUKA.",  pdg_id=1000220520)
    Ti53_MASS_EV     = constant( 49311155226.4462, "Ti53 mass in eV as used in FLUKA.",  pdg_id=1000220530)

    V46_MASS_EV      = constant( 42799937472.4909, "V46 mass in eV as used in FLUKA.",   pdg_id=1000230460)
    V47_MASS_EV      = constant( 43726501802.6187, "V47 mass in eV as used in FLUKA.",   pdg_id=1000230470)
    V48_MASS_EV      = constant( 44655525402.6827, "V48 mass in eV as used in FLUKA.",   pdg_id=1000230480)
    V49_MASS_EV      = constant( 45583538242.7729, "V49 mass in eV as used in FLUKA.",   pdg_id=1000230490)
    V50_MASS_EV      = constant( 46513771062.8056, "V50 mass in eV as used in FLUKA.",   pdg_id=1000230500)
    V51_MASS_EV      = constant( 47442285482.8828, "V51 mass in eV as used in FLUKA.",   pdg_id=1000230510)
    V52_MASS_EV      = constant( 48374539902.8631, "V52 mass in eV as used in FLUKA.",   pdg_id=1000230520)
    V53_MASS_EV      = constant( 49305626802.8737, "V53 mass in eV as used in FLUKA.",   pdg_id=1000230530)
    V54_MASS_EV      = constant( 50239078932.8230, "V54 mass in eV as used in FLUKA.",   pdg_id=1000230540)
    V55_MASS_EV      = constant( 51171312762.8038, "V55 mass in eV as used in FLUKA.",   pdg_id=1000230550)
    V56_MASS_EV      = constant( 52105797572.7263, "V56 mass in eV as used in FLUKA.",   pdg_id=1000230560)

    Cr48_MASS_EV     = constant( 44656676410.6395, "Cr48 mass in eV as used in FLUKA.",  pdg_id=1000240480)
    Cr49_MASS_EV     = constant( 45585660580.7045, "Cr49 mass in eV as used in FLUKA.",  pdg_id=1000240490)
    Cr50_MASS_EV     = constant( 46512225920.8323, "Cr50 mass in eV as used in FLUKA.",  pdg_id=1000240500)
    Cr51_MASS_EV     = constant( 47442529940.8631, "Cr51 mass in eV as used in FLUKA.",  pdg_id=1000240510)
    Cr52_MASS_EV     = constant( 48370056060.9659, "Cr52 mass in eV as used in FLUKA.",  pdg_id=1000240520)
    Cr53_MASS_EV     = constant( 49301682480.9625, "Cr53 mass in eV as used in FLUKA.",  pdg_id=1000240530)
    Cr54_MASS_EV     = constant( 50231529101.0052, "Cr54 mass in eV as used in FLUKA.",  pdg_id=1000240540)
    Cr55_MASS_EV     = constant( 51164848520.9579, "Cr55 mass in eV as used in FLUKA.",  pdg_id=1000240550)
    Cr56_MASS_EV     = constant( 52096157450.9627, "Cr56 mass in eV as used in FLUKA.",  pdg_id=1000240560)
    Cr60_MASS_EV     = constant( 55830597500.7434, "Cr60 mass in eV as used in FLUKA.",  pdg_id=1000240600)

    Mn50_MASS_EV     = constant( 46519350843.0435, "Mn50 mass in eV as used in FLUKA.",  pdg_id=1000250500)
    Mn51_MASS_EV     = constant( 47445229663.1891, "Mn51 mass in eV as used in FLUKA.",  pdg_id=1000250510)
    Mn52_MASS_EV     = constant( 48374259773.2529, "Mn52 mass in eV as used in FLUKA.",  pdg_id=1000250520)
    Mn53_MASS_EV     = constant( 49301771403.3561, "Mn53 mass in eV as used in FLUKA.",  pdg_id=1000250530)
    Mn54_MASS_EV     = constant( 50232398113.3786, "Mn54 mass in eV as used in FLUKA.",  pdg_id=1000250540)
    Mn55_MASS_EV     = constant( 51161737343.4344, "Mn55 mass in eV as used in FLUKA.",  pdg_id=1000250550)
    Mn56_MASS_EV     = constant( 52094032463.4137, "Mn56 mass in eV as used in FLUKA.",  pdg_id=1000250560)
    Mn57_MASS_EV     = constant( 53024947463.4287, "Mn57 mass in eV as used in FLUKA.",  pdg_id=1000250570)
    Mn58_MASS_EV     = constant( 53958024583.3877, "Mn58 mass in eV as used in FLUKA.",  pdg_id=1000250580)
    Mn59_MASS_EV     = constant( 54889947903.3766, "Mn59 mass in eV as used in FLUKA.",  pdg_id=1000250590)
    Mn60_MASS_EV     = constant( 55824140833.3066, "Mn60 mass in eV as used in FLUKA.",  pdg_id=1000250600)

    Fe50_MASS_EV     = constant( 46526992882.2895, "Fe50 mass in eV as used in FLUKA.",  pdg_id=1000260500)
    Fe52_MASS_EV     = constant( 48376123872.6487, "Fe52 mass in eV as used in FLUKA.",  pdg_id=1000260520)
    Fe53_MASS_EV     = constant( 49305006082.7163, "Fe53 mass in eV as used in FLUKA.",  pdg_id=1000260530)
    Fe54_MASS_EV     = constant( 50231193312.8539, "Fe54 mass in eV as used in FLUKA.",  pdg_id=1000260540)
    Fe55_MASS_EV     = constant( 51161461032.8857, "Fe55 mass in eV as used in FLUKA.",  pdg_id=1000260550)
    Fe56_MASS_EV     = constant( 52089829152.9667, "Fe56 mass in eV as used in FLUKA.",  pdg_id=1000260560)
    Fe57_MASS_EV     = constant( 53021748772.9557, "Fe57 mass in eV as used in FLUKA.",  pdg_id=1000260570)
    Fe58_MASS_EV     = constant( 53951269883.0068, "Fe58 mass in eV as used in FLUKA.",  pdg_id=1000260580)
    Fe59_MASS_EV     = constant( 54884254612.9681, "Fe59 mass in eV as used in FLUKA.",  pdg_id=1000260590)
    Fe60_MASS_EV     = constant( 55815000402.9875, "Fe60 mass in eV as used in FLUKA.",  pdg_id=1000260600)
    Fe61_MASS_EV     = constant( 56748984242.9230, "Fe61 mass in eV as used in FLUKA.",  pdg_id=1000260610)
    Fe62_MASS_EV     = constant( 57680498162.9225, "Fe62 mass in eV as used in FLUKA.",  pdg_id=1000260620)

    Co53_MASS_EV     = constant( 49312800341.5818, "Co53 mass in eV as used in FLUKA.",  pdg_id=1000270530)
    Co54_MASS_EV     = constant( 50238928571.7209, "Co54 mass in eV as used in FLUKA.",  pdg_id=1000270540)
    Co55_MASS_EV     = constant( 51164404491.8768, "Co55 mass in eV as used in FLUKA.",  pdg_id=1000270550)
    Co56_MASS_EV     = constant( 52093887401.9290, "Co56 mass in eV as used in FLUKA.",  pdg_id=1000270560)
    Co57_MASS_EV     = constant( 53022077022.0146, "Co57 mass in eV as used in FLUKA.",  pdg_id=1000270570)
    Co58_MASS_EV     = constant( 53953069642.0276, "Co58 mass in eV as used in FLUKA.",  pdg_id=1000270580)
    Co59_MASS_EV     = constant( 54882181762.0893, "Co59 mass in eV as used in FLUKA.",  pdg_id=1000270590)
    Co60_MASS_EV     = constant( 55814255492.0743, "Co60 mass in eV as used in FLUKA.",  pdg_id=1000270600)
    Co61_MASS_EV     = constant( 56744498902.1068, "Co61 mass in eV as used in FLUKA.",  pdg_id=1000270610)
    Co62_MASS_EV     = constant( 57677460222.0687, "Co62 mass in eV as used in FLUKA.",  pdg_id=1000270620)
    Co63_MASS_EV     = constant( 58608545642.0793, "Co63 mass in eV as used in FLUKA.",  pdg_id=1000270630)
    Co64_MASS_EV     = constant( 59542087662.0263, "Co64 mass in eV as used in FLUKA.",  pdg_id=1000270640)
    Co65_MASS_EV     = constant( 60474207092.0101, "Co65 mass in eV as used in FLUKA.",  pdg_id=1000270650)

    Ni56_MASS_EV     = constant( 52095515343.0931, "Ni56 mass in eV as used in FLUKA.",  pdg_id=1000280560)
    Ni57_MASS_EV     = constant( 53024833743.1495, "Ni57 mass in eV as used in FLUKA.",  pdg_id=1000280570)
    Ni58_MASS_EV     = constant( 53952180483.2570, "Ni58 mass in eV as used in FLUKA.",  pdg_id=1000280580)
    Ni59_MASS_EV     = constant( 54882746703.2811, "Ni59 mass in eV as used in FLUKA.",  pdg_id=1000280590)
    Ni60_MASS_EV     = constant( 55810924023.3670, "Ni60 mass in eV as used in FLUKA.",  pdg_id=1000280600)
    Ni61_MASS_EV     = constant( 56742669633.3605, "Ni61 mass in eV as used in FLUKA.",  pdg_id=1000280610)
    Ni62_MASS_EV     = constant( 57671638063.4260, "Ni62 mass in eV as used in FLUKA.",  pdg_id=1000280620)
    Ni63_MASS_EV     = constant( 58604365883.3940, "Ni63 mass in eV as used in FLUKA.",  pdg_id=1000280630)
    Ni64_MASS_EV     = constant( 59534273503.4351, "Ni64 mass in eV as used in FLUKA.",  pdg_id=1000280640)
    Ni65_MASS_EV     = constant( 60467741113.3840, "Ni65 mass in eV as used in FLUKA.",  pdg_id=1000280650)
    Ni66_MASS_EV     = constant( 61398329433.4074, "Ni66 mass in eV as used in FLUKA.",  pdg_id=1000280660)

    Cu58_MASS_EV     = constant( 53960236178.8527, "Cu58 mass in eV as used in FLUKA.",  pdg_id=1000290580)
    Cu59_MASS_EV     = constant( 54887038898.9743, "Cu59 mass in eV as used in FLUKA.",  pdg_id=1000290590)
    Cu60_MASS_EV     = constant( 55816543509.0258, "Cu60 mass in eV as used in FLUKA.",  pdg_id=1000290600)
    Cu61_MASS_EV     = constant( 56744399339.1201, "Cu61 mass in eV as used in FLUKA.",  pdg_id=1000290610)
    Cu62_MASS_EV     = constant( 57675078839.1412, "Cu62 mass in eV as used in FLUKA.",  pdg_id=1000290620)
    Cu63_MASS_EV     = constant( 58603791479.2133, "Cu63 mass in eV as used in FLUKA.",  pdg_id=1000290630)
    Cu64_MASS_EV     = constant( 59535441209.2093, "Cu64 mass in eV as used in FLUKA.",  pdg_id=1000290640)
    Cu65_MASS_EV     = constant( 60465097019.2569, "Cu65 mass in eV as used in FLUKA.",  pdg_id=1000290650)
    Cu66_MASS_EV     = constant( 61397596739.2309, "Cu66 mass in eV as used in FLUKA.",  pdg_id=1000290660)
    Cu67_MASS_EV     = constant( 62328044799.2580, "Cu67 mass in eV as used in FLUKA.",  pdg_id=1000290670)
    Cu68_MASS_EV     = constant( 63261297359.2124, "Cu68 mass in eV as used in FLUKA.",  pdg_id=1000290680)
    Cu70_MASS_EV     = constant( 65126867629.1455, "Cu70 mass in eV as used in FLUKA.",  pdg_id=1000290700)
    Cu71_MASS_EV     = constant( 66058558029.1404, "Cu71 mass in eV as used in FLUKA.",  pdg_id=1000290710)

    Zn61_MASS_EV     = constant( 56749529231.7960, "Zn61 mass in eV as used in FLUKA.",  pdg_id=1000300610)
    Zn62_MASS_EV     = constant( 57676198651.9210, "Zn62 mass in eV as used in FLUKA.",  pdg_id=1000300620)
    Zn63_MASS_EV     = constant( 58606651061.9480, "Zn63 mass in eV as used in FLUKA.",  pdg_id=1000300630)
    Zn64_MASS_EV     = constant( 59534355082.0462, "Zn64 mass in eV as used in FLUKA.",  pdg_id=1000300640)
    Zn65_MASS_EV     = constant( 60465941202.0438, "Zn65 mass in eV as used in FLUKA.",  pdg_id=1000300650)
    Zn66_MASS_EV     = constant( 61394447132.1213, "Zn66 mass in eV as used in FLUKA.",  pdg_id=1000300660)
    Zn67_MASS_EV     = constant( 62326960642.0949, "Zn67 mass in eV as used in FLUKA.",  pdg_id=1000300670)
    Zn68_MASS_EV     = constant( 63256328062.1500, "Zn68 mass in eV as used in FLUKA.",  pdg_id=1000300680)
    Zn69_MASS_EV     = constant( 64189411492.1088, "Zn69 mass in eV as used in FLUKA.",  pdg_id=1000300690)
    Zn70_MASS_EV     = constant( 65119761292.1385, "Zn70 mass in eV as used in FLUKA.",  pdg_id=1000300700)
    Zn71_MASS_EV     = constant( 66053493432.0805, "Zn71 mass in eV as used in FLUKA.",  pdg_id=1000300710)
    Zn72_MASS_EV     = constant( 66984183402.1013, "Zn72 mass in eV as used in FLUKA.",  pdg_id=1000300720)
    Zn73_MASS_EV     = constant( 67918394042.0309, "Zn73 mass in eV as used in FLUKA.",  pdg_id=1000300730)

    Ga62_MASS_EV     = constant( 57684862593.8657, "Ga62 mass in eV as used in FLUKA.",  pdg_id=1000310620)
    Ga63_MASS_EV     = constant( 58611664033.9873, "Ga63 mass in eV as used in FLUKA.",  pdg_id=1000310630)
    Ga64_MASS_EV     = constant( 59541012824.0429, "Ga64 mass in eV as used in FLUKA.",  pdg_id=1000310640)
    Ga65_MASS_EV     = constant( 60468689064.1419, "Ga65 mass in eV as used in FLUKA.",  pdg_id=1000310650)
    Ga66_MASS_EV     = constant( 61399115074.1695, "Ga66 mass in eV as used in FLUKA.",  pdg_id=1000310660)
    Ga67_MASS_EV     = constant( 62327454004.2513, "Ga67 mass in eV as used in FLUKA.",  pdg_id=1000310670)
    Ga68_MASS_EV     = constant( 63258742124.2567, "Ga68 mass in eV as used in FLUKA.",  pdg_id=1000310680)
    Ga69_MASS_EV     = constant( 64187998434.3146, "Ga69 mass in eV as used in FLUKA.",  pdg_id=1000310690)
    Ga70_MASS_EV     = constant( 65119909054.3038, "Ga70 mass in eV as used in FLUKA.",  pdg_id=1000310700)
    Ga71_MASS_EV     = constant( 66050173684.3357, "Ga71 mass in eV as used in FLUKA.",  pdg_id=1000310710)
    Ga72_MASS_EV     = constant( 66983218304.2955, "Ga72 mass in eV as used in FLUKA.",  pdg_id=1000310720)
    Ga73_MASS_EV     = constant( 67913593174.3246, "Ga73 mass in eV as used in FLUKA.",  pdg_id=1000310730)
    Ga74_MASS_EV     = constant( 68846737294.2818, "Ga74 mass in eV as used in FLUKA.",  pdg_id=1000310740)
    Ga75_MASS_EV     = constant( 69777821424.2924, "Ga75 mass in eV as used in FLUKA.",  pdg_id=1000310750)

    Ge65_MASS_EV     = constant( 60474424427.8315, "Ge65 mass in eV as used in FLUKA.",  pdg_id=1000320650)
    Ge66_MASS_EV     = constant( 61400708217.9665, "Ge66 mass in eV as used in FLUKA.",  pdg_id=1000320660)
    Ge67_MASS_EV     = constant( 62331169917.9933, "Ge67 mass in eV as used in FLUKA.",  pdg_id=1000320670)
    Ge68_MASS_EV     = constant( 63258341128.1053, "Ge68 mass in eV as used in FLUKA.",  pdg_id=1000320680)
    Ge69_MASS_EV     = constant( 64189718878.1083, "Ge69 mass in eV as used in FLUKA.",  pdg_id=1000320690)
    Ge70_MASS_EV     = constant( 65117746418.1982, "Ge70 mass in eV as used in FLUKA.",  pdg_id=1000320700)
    Ge71_MASS_EV     = constant( 66049896228.1812, "Ge71 mass in eV as used in FLUKA.",  pdg_id=1000320710)
    Ge72_MASS_EV     = constant( 66978710348.2507, "Ge72 mass in eV as used in FLUKA.",  pdg_id=1000320720)
    Ge73_MASS_EV     = constant( 67911493078.2173, "Ge73 mass in eV as used in FLUKA.",  pdg_id=1000320730)
    Ge74_MASS_EV     = constant( 68840862498.2723, "Ge74 mass in eV as used in FLUKA.",  pdg_id=1000320740)
    Ge75_MASS_EV     = constant( 69773922918.2317, "Ge75 mass in eV as used in FLUKA.",  pdg_id=1000320750)
    Ge76_MASS_EV     = constant( 70704060328.2669, "Ge76 mass in eV as used in FLUKA.",  pdg_id=1000320760)
    Ge77_MASS_EV     = constant( 71637553348.2151, "Ge77 mass in eV as used in FLUKA.",  pdg_id=1000320770)

    As66_MASS_EV     = constant( 61410000975.4967, "As66 mass in eV as used in FLUKA.",  pdg_id=1000330660)
    As67_MASS_EV     = constant( 62336673285.6217, "As67 mass in eV as used in FLUKA.",  pdg_id=1000330670)
    As68_MASS_EV     = constant( 63265934505.6795, "As68 mass in eV as used in FLUKA.",  pdg_id=1000330680)
    As69_MASS_EV     = constant( 64193225205.7885, "As69 mass in eV as used in FLUKA.",  pdg_id=1000330690)
    As70_MASS_EV     = constant( 65123459705.8211, "As70 mass in eV as used in FLUKA.",  pdg_id=1000330700)
    As71_MASS_EV     = constant( 66051402225.9132, "As71 mass in eV as used in FLUKA.",  pdg_id=1000330710)
    As72_MASS_EV     = constant( 66982559755.9219, "As72 mass in eV as used in FLUKA.",  pdg_id=1000330720)
    As73_MASS_EV     = constant( 67911327275.9925, "As73 mass in eV as used in FLUKA.",  pdg_id=1000330730)
    As74_MASS_EV     = constant( 68842918215.9900, "As74 mass in eV as used in FLUKA.",  pdg_id=1000330740)
    As75_MASS_EV     = constant( 69772239736.0464, "As75 mass in eV as used in FLUKA.",  pdg_id=1000330750)
    As76_MASS_EV     = constant( 70704476966.0271, "As76 mass in eV as used in FLUKA.",  pdg_id=1000330760)
    As77_MASS_EV     = constant( 71634344676.0693, "As77 mass in eV as used in FLUKA.",  pdg_id=1000330770)
    As78_MASS_EV     = constant( 72566938916.0408, "As78 mass in eV as used in FLUKA.",  pdg_id=1000330780)
    As78_MASS_EV     = constant( 72566938916.0408, "As78 mass in eV as used in FLUKA.",  pdg_id=1000330780)
    As81_MASS_EV     = constant( 75361705426.0334, "As81 mass in eV as used in FLUKA.",  pdg_id=1000330810)
    As82_MASS_EV     = constant( 76295493635.9740, "As82 mass in eV as used in FLUKA.",  pdg_id=1000330820)

    Se69_MASS_EV     = constant( 64199501809.5504, "Se69 mass in eV as used in FLUKA.",  pdg_id=1000340690)
    Se70_MASS_EV     = constant( 65125352759.6967, "Se70 mass in eV as used in FLUKA.",  pdg_id=1000340700)
    Se71_MASS_EV     = constant( 66055695089.7265, "Se71 mass in eV as used in FLUKA.",  pdg_id=1000340710)
    Se72_MASS_EV     = constant( 66982388299.8509, "Se72 mass in eV as used in FLUKA.",  pdg_id=1000340720)
    Se73_MASS_EV     = constant( 67913560819.8593, "Se73 mass in eV as used in FLUKA.",  pdg_id=1000340730)
    Se74_MASS_EV     = constant( 68841058729.9628, "Se74 mass in eV as used in FLUKA.",  pdg_id=1000340740)
    Se75_MASS_EV     = constant( 69772596849.9617, "Se75 mass in eV as used in FLUKA.",  pdg_id=1000340750)
    Se76_MASS_EV     = constant( 70701008480.0416, "Se76 mass in eV as used in FLUKA.",  pdg_id=1000340760)
    Se77_MASS_EV     = constant( 71633155290.0247, "Se77 mass in eV as used in FLUKA.",  pdg_id=1000340770)
    Se78_MASS_EV     = constant( 72562223020.0876, "Se78 mass in eV as used in FLUKA.",  pdg_id=1000340780)
    Se79_MASS_EV     = constant( 73494825740.0588, "Se79 mass in eV as used in FLUKA.",  pdg_id=1000340790)
    Se80_MASS_EV     = constant( 74424477950.1066, "Se80 mass in eV as used in FLUKA.",  pdg_id=1000340800)
    Se81_MASS_EV     = constant( 75357342570.0710, "Se81 mass in eV as used in FLUKA.",  pdg_id=1000340810)

    Br71_MASS_EV     = constant( 66061688691.8296, "Br71 mass in eV as used in FLUKA.",  pdg_id=1000350710)
    Br72_MASS_EV     = constant( 66990596491.8966, "Br72 mass in eV as used in FLUKA.",  pdg_id=1000350720)
    Br73_MASS_EV     = constant( 67917710922.0101, "Br73 mass in eV as used in FLUKA.",  pdg_id=1000350730)
    Br74_MASS_EV     = constant( 68847459132.0553, "Br74 mass in eV as used in FLUKA.",  pdg_id=1000350740)
    Br75_MASS_EV     = constant( 69775120562.1546, "Br75 mass in eV as used in FLUKA.",  pdg_id=1000350750)
    Br76_MASS_EV     = constant( 70705464992.1845, "Br76 mass in eV as used in FLUKA.",  pdg_id=1000350760)
    Br77_MASS_EV     = constant( 71634014082.2608, "Br77 mass in eV as used in FLUKA.",  pdg_id=1000350770)
    Br78_MASS_EV     = constant( 72565290392.2664, "Br78 mass in eV as used in FLUKA.",  pdg_id=1000350780)
    Br79_MASS_EV     = constant( 73494168732.3342, "Br79 mass in eV as used in FLUKA.",  pdg_id=1000350790)
    Br80_MASS_EV     = constant( 74425842252.3296, "Br80 mass in eV as used in FLUKA.",  pdg_id=1000350800)
    Br81_MASS_EV     = constant( 75355251162.3836, "Br81 mass in eV as used in FLUKA.",  pdg_id=1000350810)
    Br82_MASS_EV     = constant( 76287223882.3712, "Br82 mass in eV as used in FLUKA.",  pdg_id=1000350820)
    Br83_MASS_EV     = constant( 77217205482.4104, "Br83 mass in eV as used in FLUKA.",  pdg_id=1000350830)
    Br88_MASS_EV     = constant( 81882957692.1959, "Br88 mass in eV as used in FLUKA.",  pdg_id=1000350880)

    Kr73_MASS_EV     = constant( 67923879414.5838, "Kr73 mass in eV as used in FLUKA.",  pdg_id=1000360730)
    Kr74_MASS_EV     = constant( 68850090684.7207, "Kr74 mass in eV as used in FLUKA.",  pdg_id=1000360740)
    Kr75_MASS_EV     = constant( 69779513054.7744, "Kr75 mass in eV as used in FLUKA.",  pdg_id=1000360750)
    Kr76_MASS_EV     = constant( 70706270274.8972, "Kr76 mass in eV as used in FLUKA.",  pdg_id=1000360760)
    Kr77_MASS_EV     = constant( 71636571614.9281, "Kr77 mass in eV as used in FLUKA.",  pdg_id=1000360770)
    Kr78_MASS_EV     = constant( 72564077865.0314, "Kr78 mass in eV as used in FLUKA.",  pdg_id=1000360780)
    Kr79_MASS_EV     = constant( 73495288405.0388, "Kr79 mass in eV as used in FLUKA.",  pdg_id=1000360790)
    Kr80_MASS_EV     = constant( 74423331825.1282, "Kr80 mass in eV as used in FLUKA.",  pdg_id=1000360800)
    Kr81_MASS_EV     = constant( 75355025755.1230, "Kr81 mass in eV as used in FLUKA.",  pdg_id=1000360810)
    Kr82_MASS_EV     = constant( 76283625175.1981, "Kr82 mass in eV as used in FLUKA.",  pdg_id=1000360820)
    Kr83_MASS_EV     = constant( 77215727085.1823, "Kr83 mass in eV as used in FLUKA.",  pdg_id=1000360830)
    Kr84_MASS_EV     = constant( 78144772315.2458, "Kr84 mass in eV as used in FLUKA.",  pdg_id=1000360840)
    Kr85_MASS_EV     = constant( 79077218535.2211, "Kr85 mass in eV as used in FLUKA.",  pdg_id=1000360850)
    Kr86_MASS_EV     = constant( 80006929135.2673, "Kr86 mass in eV as used in FLUKA.",  pdg_id=1000360860)

    Rb76_MASS_EV     = constant( 70714264690.0032, "Rb76 mass in eV as used in FLUKA.",  pdg_id=1000370760)
    Rb77_MASS_EV     = constant( 71641410210.1158, "Rb77 mass in eV as used in FLUKA.",  pdg_id=1000370770)
    Rb78_MASS_EV     = constant( 72570796330.1705, "Rb78 mass in eV as used in FLUKA.",  pdg_id=1000370780)
    Rb79_MASS_EV     = constant( 73498431770.2705, "Rb79 mass in eV as used in FLUKA.",  pdg_id=1000370790)
    Rb80_MASS_EV     = constant( 74428548780.3062, "Rb80 mass in eV as used in FLUKA.",  pdg_id=1000370800)
    Rb81_MASS_EV     = constant( 75356757810.3913, "Rb81 mass in eV as used in FLUKA.",  pdg_id=1000370810)
    Rb82_MASS_EV     = constant( 76287520620.4102, "Rb82 mass in eV as used in FLUKA.",  pdg_id=1000370820)
    Rb83_MASS_EV     = constant( 77216130210.4850, "Rb83 mass in eV as used in FLUKA.",  pdg_id=1000370830)
    Rb84_MASS_EV     = constant( 78146947700.5025, "Rb84 mass in eV as used in FLUKA.",  pdg_id=1000370840)
    Rb85_MASS_EV     = constant( 79076025620.5652, "Rb85 mass in eV as used in FLUKA.",  pdg_id=1000370850)
    Rb86_MASS_EV     = constant( 80006940040.5802, "Rb86 mass in eV as used in FLUKA.",  pdg_id=1000370860)
    Rb87_MASS_EV     = constant( 80936586160.6281, "Rb87 mass in eV as used in FLUKA.",  pdg_id=1000370870)
    Rb90_MASS_EV     = constant( 83736310670.4923, "Rb90 mass in eV as used in FLUKA.",  pdg_id=1000370900)

    Sr79_MASS_EV     = constant( 73503244220.1075, "Sr79 mass in eV as used in FLUKA.",  pdg_id=1000380790)
    Sr80_MASS_EV     = constant( 74429911050.2326, "Sr80 mass in eV as used in FLUKA.",  pdg_id=1000380800)
    Sr81_MASS_EV     = constant( 75360183670.2643, "Sr81 mass in eV as used in FLUKA.",  pdg_id=1000380810)
    Sr82_MASS_EV     = constant( 76287195210.3804, "Sr82 mass in eV as used in FLUKA.",  pdg_id=1000380820)
    Sr83_MASS_EV     = constant( 77217900700.4009, "Sr83 mass in eV as used in FLUKA.",  pdg_id=1000380830)
    Sr84_MASS_EV     = constant( 78145547680.5006, "Sr84 mass in eV as used in FLUKA.",  pdg_id=1000380840)
    Sr85_MASS_EV     = constant( 79076584690.5124, "Sr85 mass in eV as used in FLUKA.",  pdg_id=1000380850)
    Sr86_MASS_EV     = constant( 80004659630.6011, "Sr86 mass in eV as used in FLUKA.",  pdg_id=1000380860)
    Sr87_MASS_EV     = constant( 80935797150.6103, "Sr87 mass in eV as used in FLUKA.",  pdg_id=1000380870)
    Sr88_MASS_EV     = constant( 81864250160.6891, "Sr88 mass in eV as used in FLUKA.",  pdg_id=1000380880)
    Sr89_MASS_EV     = constant( 82797457080.6447, "Sr89 mass in eV as used in FLUKA.",  pdg_id=1000380890)
    Sr90_MASS_EV     = constant( 83729215200.6379, "Sr90 mass in eV as used in FLUKA.",  pdg_id=1000380900)
    Sr91_MASS_EV     = constant( 84663001380.5785, "Sr91 mass in eV as used in FLUKA.",  pdg_id=1000380910)
    Sr95_MASS_EV     = constant( 88397469020.3585, "Sr95 mass in eV as used in FLUKA.",  pdg_id=1000380950)

    Y79_MASS_EV      = constant( 73509858736.5816, "Y79 mass in eV as used in FLUKA.",   pdg_id=1000390790)
    Y80_MASS_EV      = constant( 74438545206.6544, "Y80 mass in eV as used in FLUKA.",   pdg_id=1000390800)
    Y81_MASS_EV      = constant( 75365188566.7801, "Y81 mass in eV as used in FLUKA.",   pdg_id=1000390810)
    Y82_MASS_EV      = constant( 76294505736.8365, "Y82 mass in eV as used in FLUKA.",   pdg_id=1000390820)
    Y83_MASS_EV      = constant( 77221861226.9438, "Y83 mass in eV as used in FLUKA.",   pdg_id=1000390830)
    Y84_MASS_EV      = constant( 78151452166.9931, "Y84 mass in eV as used in FLUKA.",   pdg_id=1000390840)
    Y85_MASS_EV      = constant( 79079333777.0867, "Y85 mass in eV as used in FLUKA.",   pdg_id=1000390850)
    Y86_MASS_EV      = constant( 80009394117.1239, "Y86 mass in eV as used in FLUKA.",   pdg_id=1000390860)
    Y87_MASS_EV      = constant( 80937153217.2207, "Y87 mass in eV as used in FLUKA.",   pdg_id=1000390870)
    Y88_MASS_EV      = constant( 81867367237.2538, "Y88 mass in eV as used in FLUKA.",   pdg_id=1000390880)
    Y89_MASS_EV      = constant( 82795454967.3421, "Y89 mass in eV as used in FLUKA.",   pdg_id=1000390890)
    Y90_MASS_EV      = constant( 83728163477.3107, "Y90 mass in eV as used in FLUKA.",   pdg_id=1000390900)
    Y91_MASS_EV      = constant( 84659796597.3071, "Y91 mass in eV as used in FLUKA.",   pdg_id=1000390910)
    Y93_MASS_EV      = constant( 86524888857.2526, "Y93 mass in eV as used in FLUKA.",   pdg_id=1000390930)

    Zr82_MASS_EV     = constant( 76298000372.0780, "Zr82 mass in eV as used in FLUKA.",  pdg_id=1000400820)
    Zr84_MASS_EV     = constant( 78153687272.2672, "Zr84 mass in eV as used in FLUKA.",  pdg_id=1000400840)
    Zr85_MASS_EV     = constant( 79083521472.3102, "Zr85 mass in eV as used in FLUKA.",  pdg_id=1000400850)
    Zr86_MASS_EV     = constant( 80010361772.4308, "Zr86 mass in eV as used in FLUKA.",  pdg_id=1000400860)
    Zr87_MASS_EV     = constant( 80940313242.4708, "Zr87 mass in eV as used in FLUKA.",  pdg_id=1000400870)
    Zr88_MASS_EV     = constant( 81867531732.5817, "Zr88 mass in eV as used in FLUKA.",  pdg_id=1000400880)
    Zr89_MASS_EV     = constant( 82797781932.6139, "Zr89 mass in eV as used in FLUKA.",  pdg_id=1000400890)
    Zr90_MASS_EV     = constant( 83725376152.7150, "Zr90 mass in eV as used in FLUKA.",  pdg_id=1000400900)
    Zr91_MASS_EV     = constant( 84657747182.6922, "Zr91 mass in eV as used in FLUKA.",  pdg_id=1000400910)
    Zr92_MASS_EV     = constant( 85588678102.7068, "Zr92 mass in eV as used in FLUKA.",  pdg_id=1000400920)
    Zr93_MASS_EV     = constant( 86521509622.6722, "Zr93 mass in eV as used in FLUKA.",  pdg_id=1000400930)
    Zr94_MASS_EV     = constant( 87452855142.6760, "Zr94 mass in eV as used in FLUKA.",  pdg_id=1000400940)
    Zr95_MASS_EV     = constant( 88385958162.6343, "Zr95 mass in eV as used in FLUKA.",  pdg_id=1000400950)
    Zr96_MASS_EV     = constant( 89317669872.6287, "Zr96 mass in eV as used in FLUKA.",  pdg_id=1000400960)

    Nb84_MASS_EV     = constant( 78162795038.0215, "Nb84 mass in eV as used in FLUKA.",  pdg_id=1000410840)
    Nb86_MASS_EV     = constant( 80017834598.2275, "Nb86 mass in eV as used in FLUKA.",  pdg_id=1000410860)
    Nb87_MASS_EV     = constant( 80944977138.3402, "Nb87 mass in eV as used in FLUKA.",  pdg_id=1000410870)
    Nb88_MASS_EV     = constant( 81874226518.3984, "Nb88 mass in eV as used in FLUKA.",  pdg_id=1000410880)
    Nb89_MASS_EV     = constant( 82801566698.5061, "Nb89 mass in eV as used in FLUKA.",  pdg_id=1000410890)
    Nb90_MASS_EV     = constant( 83730982008.5600, "Nb90 mass in eV as used in FLUKA.",  pdg_id=1000410900)
    Nb91_MASS_EV     = constant( 84658495448.6631, "Nb91 mass in eV as used in FLUKA.",  pdg_id=1000410910)
    Nb92_MASS_EV     = constant( 85590178668.6582, "Nb92 mass in eV as used in FLUKA.",  pdg_id=1000410920)
    Nb93_MASS_EV     = constant( 86520913298.6779, "Nb93 mass in eV as used in FLUKA.",  pdg_id=1000410930)
    Nb94_MASS_EV     = constant( 87453251518.6560, "Nb94 mass in eV as used in FLUKA.",  pdg_id=1000410940)
    Nb95_MASS_EV     = constant( 88384328638.6668, "Nb95 mass in eV as used in FLUKA.",  pdg_id=1000410950)
    Nb96_MASS_EV     = constant( 89317001138.6363, "Nb96 mass in eV as used in FLUKA.",  pdg_id=1000410960)
    Nb97_MASS_EV     = constant( 90248492768.6364, "Nb97 mass in eV as used in FLUKA.",  pdg_id=1000410970)
    Nb99_MASS_EV     = constant( 92114760918.5514, "Nb99 mass in eV as used in FLUKA.",  pdg_id=1000410990)

    Mo87_MASS_EV     = constant( 80950958556.7755, "Mo87 mass in eV as used in FLUKA.",  pdg_id=1000420870)
    Mo88_MASS_EV     = constant( 81877445376.9053, "Mo88 mass in eV as used in FLUKA.",  pdg_id=1000420880)
    Mo89_MASS_EV     = constant( 82806636896.9650, "Mo89 mass in eV as used in FLUKA.",  pdg_id=1000420890)
    Mo90_MASS_EV     = constant( 83732966077.0988, "Mo90 mass in eV as used in FLUKA.",  pdg_id=1000420900)
    Mo91_MASS_EV     = constant( 84662424347.1516, "Mo91 mass in eV as used in FLUKA.",  pdg_id=1000420910)
    Mo92_MASS_EV     = constant( 85589317647.2708, "Mo92 mass in eV as used in FLUKA.",  pdg_id=1000420920)
    Mo93_MASS_EV     = constant( 86520813667.2708, "Mo93 mass in eV as used in FLUKA.",  pdg_id=1000420930)
    Mo94_MASS_EV     = constant( 87450701497.3124, "Mo94 mass in eV as used in FLUKA.",  pdg_id=1000420940)
    Mo95_MASS_EV     = constant( 88382898117.2942, "Mo95 mass in eV as used in FLUKA.",  pdg_id=1000420950)
    Mo96_MASS_EV     = constant( 89313309437.3223, "Mo96 mass in eV as used in FLUKA.",  pdg_id=1000420960)
    Mo97_MASS_EV     = constant( 90246053957.2898, "Mo97 mass in eV as used in FLUKA.",  pdg_id=1000420970)
    Mo99_MASS_EV     = constant( 92110617397.2491, "Mo99 mass in eV as used in FLUKA.",  pdg_id=1000420990)
    Mo100_MASS_EV    = constant( 93041893477.2547, "Mo100 mass in eV as used in FLUKA.", pdg_id=1000421000)
    Mo101_MASS_EV    = constant( 93976060597.1855, "Mo101 mass in eV as used in FLUKA.", pdg_id=1000421010)
    Mo102_MASS_EV    = constant( 94907508957.1867, "Mo102 mass in eV as used in FLUKA.", pdg_id=1000421020)

    Tc90_MASS_EV     = constant( 83741601419.9785, "Tc90 mass in eV as used in FLUKA.",  pdg_id=1000430900)
    Tc91_MASS_EV     = constant( 84668139620.1069, "Tc91 mass in eV as used in FLUKA.",  pdg_id=1000430910)
    Tc92_MASS_EV     = constant( 85596683100.1834, "Tc92 mass in eV as used in FLUKA.",  pdg_id=1000430920)
    Tc93_MASS_EV     = constant( 86523509740.3043, "Tc93 mass in eV as used in FLUKA.",  pdg_id=1000430930)
    Tc94_MASS_EV     = constant( 87454452560.3186, "Tc94 mass in eV as used in FLUKA.",  pdg_id=1000430940)
    Tc95_MASS_EV     = constant( 88384084760.3669, "Tc95 mass in eV as used in FLUKA.",  pdg_id=1000430950)
    Tc96_MASS_EV     = constant( 89315777980.3617, "Tc96 mass in eV as used in FLUKA.",  pdg_id=1000430960)
    Tc97_MASS_EV     = constant( 90245869520.3981, "Tc97 mass in eV as used in FLUKA.",  pdg_id=1000430970)
    Tc98_MASS_EV     = constant( 91178156440.3775, "Tc98 mass in eV as used in FLUKA.",  pdg_id=1000430980)
    Tc99_MASS_EV     = constant( 92108755380.4007, "Tc99 mass in eV as used in FLUKA.",  pdg_id=1000430990)
    Tc100_MASS_EV    = constant( 93041556700.3669, "Tc100 mass in eV as used in FLUKA.", pdg_id=1000431000)
    Tc101_MASS_EV    = constant( 93972731520.3752, "Tc101 mass in eV as used in FLUKA.", pdg_id=1000431010)
    Tc102_MASS_EV    = constant( 94905994260.3293, "Tc102 mass in eV as used in FLUKA.", pdg_id=1000431020)

    Ru91_MASS_EV     = constant( 84675040179.4302, "Ru91 mass in eV as used in FLUKA.",  pdg_id=1000440910)
    Ru93_MASS_EV     = constant( 86529342189.6553, "Ru93 mass in eV as used in FLUKA.",  pdg_id=1000440930)
    Ru94_MASS_EV     = constant( 87455540969.7926, "Ru94 mass in eV as used in FLUKA.",  pdg_id=1000440940)
    Ru95_MASS_EV     = constant( 88386152699.8154, "Ru95 mass in eV as used in FLUKA.",  pdg_id=1000440950)
    Ru96_MASS_EV     = constant( 89315025349.8834, "Ru96 mass in eV as used in FLUKA.",  pdg_id=1000440960)
    Ru97_MASS_EV     = constant( 90246479459.8844, "Ru97 mass in eV as used in FLUKA.",  pdg_id=1000440970)
    Ru98_MASS_EV     = constant( 91175856109.9393, "Ru98 mass in eV as used in FLUKA.",  pdg_id=1000440980)
    Ru99_MASS_EV     = constant( 92107957369.9236, "Ru99 mass in eV as used in FLUKA.",  pdg_id=1000440990)
    Ru100_MASS_EV    = constant( 93037849889.9651, "Ru100 mass in eV as used in FLUKA.", pdg_id=1000441000)
    Ru101_MASS_EV    = constant( 93970613409.9322, "Ru101 mass in eV as used in FLUKA.", pdg_id=1000441010)
    Ru102_MASS_EV    = constant( 94900959529.9620, "Ru102 mass in eV as used in FLUKA.", pdg_id=1000441020)
    Ru103_MASS_EV    = constant( 95834292749.9143, "Ru103 mass in eV as used in FLUKA.", pdg_id=1000441030)
    Ru104_MASS_EV    = constant( 96764954849.9358, "Ru104 mass in eV as used in FLUKA.", pdg_id=1000441040)
    Ru106_MASS_EV    = constant( 98629711249.8900, "Ru106 mass in eV as used in FLUKA.", pdg_id=1000441060)

    Rh94_MASS_EV     = constant( 87464665737.3159, "Rh94 mass in eV as used in FLUKA.",  pdg_id=1000450940)
    Rh95_MASS_EV     = constant( 88390758397.4559, "Rh95 mass in eV as used in FLUKA.",  pdg_id=1000450950)
    Rh96_MASS_EV     = constant( 89320967507.4892, "Rh96 mass in eV as used in FLUKA.",  pdg_id=1000450960)
    Rh97_MASS_EV     = constant( 90249498207.5660, "Rh97 mass in eV as used in FLUKA.",  pdg_id=1000450970)
    Rh98_MASS_EV     = constant( 91180409257.5811, "Rh98 mass in eV as used in FLUKA.",  pdg_id=1000450980)
    Rh99_MASS_EV     = constant( 92109556077.6419, "Rh99 mass in eV as used in FLUKA.",  pdg_id=1000450990)
    Rh100_MASS_EV    = constant( 93040975587.6439, "Rh100 mass in eV as used in FLUKA.", pdg_id=1000451000)
    Rh101_MASS_EV    = constant( 93970650717.6910, "Rh101 mass in eV as used in FLUKA.", pdg_id=1000451010)
    Rh102_MASS_EV    = constant( 94902777797.6746, "Rh102 mass in eV as used in FLUKA.", pdg_id=1000451020)
    Rh103_MASS_EV    = constant( 95833025137.7069, "Rh103 mass in eV as used in FLUKA.", pdg_id=1000451030)
    Rh104_MASS_EV    = constant( 96765591757.6791, "Rh104 mass in eV as used in FLUKA.", pdg_id=1000451040)
    Rh105_MASS_EV    = constant( 97696189057.7024, "Rh105 mass in eV as used in FLUKA.", pdg_id=1000451050)
    Rh106_MASS_EV    = constant( 98629167547.6639, "Rh106 mass in eV as used in FLUKA.", pdg_id=1000451060)
    Rh107_MASS_EV    = constant( 99560164227.6768, "Rh107 mass in eV as used in FLUKA.", pdg_id=1000451070)
    Rh108_MASS_EV    = constant(100493503257.6290, "Rh108 mass in eV as used in FLUKA.", pdg_id=1000451080)

    Pd96_MASS_EV     = constant( 89323913415.2637, "Pd96 mass in eV as used in FLUKA.",  pdg_id=1000460960)
    Pd97_MASS_EV     = constant( 90253784125.3057, "Pd97 mass in eV as used in FLUKA.",  pdg_id=1000460970)
    Pd98_MASS_EV     = constant( 91181777755.3965, "Pd98 mass in eV as used in FLUKA.",  pdg_id=1000460980)
    Pd99_MASS_EV     = constant( 92112417285.4186, "Pd99 mass in eV as used in FLUKA.",  pdg_id=1000460990)
    Pd100_MASS_EV    = constant( 93040834405.4984, "Pd100 mass in eV as used in FLUKA.", pdg_id=1000461000)
    Pd101_MASS_EV    = constant( 93972126615.5036, "Pd101 mass in eV as used in FLUKA.", pdg_id=1000461010)
    Pd102_MASS_EV    = constant( 94901123225.5683, "Pd102 mass in eV as used in FLUKA.", pdg_id=1000461020)
    Pd103_MASS_EV    = constant( 95833064145.5567, "Pd103 mass in eV as used in FLUKA.", pdg_id=1000461030)
    Pd104_MASS_EV    = constant( 96762646645.6063, "Pd104 mass in eV as used in FLUKA.", pdg_id=1000461040)
    Pd105_MASS_EV    = constant( 97695118275.5810, "Pd105 mass in eV as used in FLUKA.", pdg_id=1000461050)
    Pd106_MASS_EV    = constant( 98625122385.6196, "Pd106 mass in eV as used in FLUKA.", pdg_id=1000461060)

    Ag98_MASS_EV     = constant( 91189693874.9419, "Ag98 mass in eV as used in FLUKA.",  pdg_id=1000470980)
    Ag99_MASS_EV     = constant( 92117343405.0415, "Ag99 mass in eV as used in FLUKA.",  pdg_id=1000470990)
    Ag100_MASS_EV    = constant( 93047403955.0787, "Ag100 mass in eV as used in FLUKA.", pdg_id=1000471000)
    Ag101_MASS_EV    = constant( 93975826545.1583, "Ag101 mass in eV as used in FLUKA.", pdg_id=1000471010)
    Ag102_MASS_EV    = constant( 94906542515.1785, "Ag102 mass in eV as used in FLUKA.", pdg_id=1000471020)
    Ag103_MASS_EV    = constant( 95835248275.2507, "Ag103 mass in eV as used in FLUKA.", pdg_id=1000471030)
    Ag104_MASS_EV    = constant( 96766421455.2590, "Ag104 mass in eV as used in FLUKA.", pdg_id=1000471040)
    Ag105_MASS_EV    = constant( 97695960025.3097, "Ag105 mass in eV as used in FLUKA.", pdg_id=1000471050)
    Ag106_MASS_EV    = constant( 98627583805.3064, "Ag106 mass in eV as used in FLUKA.", pdg_id=1000471060)
    Ag107_MASS_EV    = constant( 99557612115.3444, "Ag107 mass in eV as used in FLUKA.", pdg_id=1000471070)
    Ag108_MASS_EV    = constant(100489908245.3236, "Ag108 mass in eV as used in FLUKA.", pdg_id=1000471080)
    Ag109_MASS_EV    = constant(101420286685.3525, "Ag109 mass in eV as used in FLUKA.", pdg_id=1000471090)
    Ag110_MASS_EV    = constant(102353043105.3198, "Ag110 mass in eV as used in FLUKA.", pdg_id=1000471100)
    Ag111_MASS_EV    = constant(103283777625.3395, "Ag111 mass in eV as used in FLUKA.", pdg_id=1000471110)
    Ag114_MASS_EV    = constant(106081533085.2547, "Ag114 mass in eV as used in FLUKA.", pdg_id=1000471140)

    Cd101_MASS_EV    = constant( 93980799478.4646, "Cd101 mass in eV as used in FLUKA.", pdg_id=1000481010)
    Cd102_MASS_EV    = constant( 94908625958.5596, "Cd102 mass in eV as used in FLUKA.", pdg_id=1000481020)
    Cd103_MASS_EV    = constant( 95838886508.5916, "Cd103 mass in eV as used in FLUKA.", pdg_id=1000481030)
    Cd104_MASS_EV    = constant( 96767054648.6778, "Cd104 mass in eV as used in FLUKA.", pdg_id=1000481040)
    Cd105_MASS_EV    = constant( 97698195058.6870, "Cd105 mass in eV as used in FLUKA.", pdg_id=1000481050)
    Cd106_MASS_EV    = constant( 98626885528.7596, "Cd106 mass in eV as used in FLUKA.", pdg_id=1000481060)
    Cd107_MASS_EV    = constant( 99558525438.7558, "Cd107 mass in eV as used in FLUKA.", pdg_id=1000481070)
    Cd108_MASS_EV    = constant(100487755068.8145, "Cd108 mass in eV as used in FLUKA.", pdg_id=1000481080)
    Cd109_MASS_EV    = constant(101419996808.7951, "Cd109 mass in eV as used in FLUKA.", pdg_id=1000481090)
    Cd110_MASS_EV    = constant(102349647338.8429, "Cd110 mass in eV as used in FLUKA.", pdg_id=1000481100)
    Cd111_MASS_EV    = constant(103282237158.8145, "Cd111 mass in eV as used in FLUKA.", pdg_id=1000481110)
    Cd112_MASS_EV    = constant(104212404678.8489, "Cd112 mass in eV as used in FLUKA.", pdg_id=1000481120)
    Cd113_MASS_EV    = constant(105145430098.8092, "Cd113 mass in eV as used in FLUKA.", pdg_id=1000481130)
    Cd114_MASS_EV    = constant(106075953018.8344, "Cd114 mass in eV as used in FLUKA.", pdg_id=1000481140)
    Cd116_MASS_EV    = constant(107940243158.8007, "Cd116 mass in eV as used in FLUKA.", pdg_id=1000481160)
    Cd119_MASS_EV    = constant(110739540488.6759, "Cd119 mass in eV as used in FLUKA.", pdg_id=1000481190)

    In103_MASS_EV    = constant( 95844433057.3294, "In103 mass in eV as used in FLUKA.", pdg_id=1000491030)
    In104_MASS_EV    = constant( 96774459987.3674, "In104 mass in eV as used in FLUKA.", pdg_id=1000491040)
    In105_MASS_EV    = constant( 97702540597.4559, "In105 mass in eV as used in FLUKA.", pdg_id=1000491050)
    In106_MASS_EV    = constant( 98632903427.4852, "In106 mass in eV as used in FLUKA.", pdg_id=1000491060)
    In107_MASS_EV    = constant( 99561448047.5616, "In107 mass in eV as used in FLUKA.", pdg_id=1000491070)
    In108_MASS_EV    = constant(100492399267.5757, "In108 mass in eV as used in FLUKA.", pdg_id=1000491080)
    In109_MASS_EV    = constant(101421513637.6374, "In109 mass in eV as used in FLUKA.", pdg_id=1000491090)
    In110_MASS_EV    = constant(102353021807.6370, "In110 mass in eV as used in FLUKA.", pdg_id=1000491100)
    In111_MASS_EV    = constant(103282599587.6867, "In111 mass in eV as used in FLUKA.", pdg_id=1000491110)
    In112_MASS_EV    = constant(104214487407.6765, "In112 mass in eV as used in FLUKA.", pdg_id=1000491120)
    In113_MASS_EV    = constant(105144610747.7120, "In113 mass in eV as used in FLUKA.", pdg_id=1000491130)
    In114_MASS_EV    = constant(106076902057.6913, "In114 mass in eV as used in FLUKA.", pdg_id=1000491140)
    In115_MASS_EV    = constant(107007428677.7164, "In115 mass in eV as used in FLUKA.", pdg_id=1000491150)
    In116_MASS_EV    = constant(107940209987.6831, "In116 mass in eV as used in FLUKA.", pdg_id=1000491160)
    In118_MASS_EV    = constant(109804219297.6566, "In118 mass in eV as used in FLUKA.", pdg_id=1000491180)
    In120_MASS_EV    = constant(111668704877.6178, "In120 mass in eV as used in FLUKA.", pdg_id=1000491200)

    Sn106_MASS_EV    = constant( 98635584553.4832, "Sn106 mass in eV as used in FLUKA.", pdg_id=1000501060)
    Sn107_MASS_EV    = constant( 99565944443.5126, "Sn107 mass in eV as used in FLUKA.", pdg_id=1000501070)
    Sn108_MASS_EV    = constant(100493988113.6020, "Sn108 mass in eV as used in FLUKA.", pdg_id=1000501080)
    Sn109_MASS_EV    = constant(101424860763.6181, "Sn109 mass in eV as used in FLUKA.", pdg_id=1000501090)
    Sn110_MASS_EV    = constant(102353156263.7010, "Sn110 mass in eV as used in FLUKA.", pdg_id=1000501100)
    Sn111_MASS_EV    = constant(103284541233.7039, "Sn111 mass in eV as used in FLUKA.", pdg_id=1000501110)
    Sn112_MASS_EV    = constant(104213320683.7742, "Sn112 mass in eV as used in FLUKA.", pdg_id=1000501120)
    Sn113_MASS_EV    = constant(105145143403.7657, "Sn113 mass in eV as used in FLUKA.", pdg_id=1000501130)
    Sn114_MASS_EV    = constant(106074410133.8234, "Sn114 mass in eV as used in FLUKA.", pdg_id=1000501140)
    Sn115_MASS_EV    = constant(107006430153.8098, "Sn115 mass in eV as used in FLUKA.", pdg_id=1000501150)
    Sn117_MASS_EV    = constant(108869053493.8193, "Sn117 mass in eV as used in FLUKA.", pdg_id=1000501170)

    Sb109_MASS_EV    = constant(101430737828.4374, "Sb109 mass in eV as used in FLUKA.", pdg_id=1000511090)
    Sb110_MASS_EV    = constant(102360952768.4705, "Sb110 mass in eV as used in FLUKA.", pdg_id=1000511100)
    Sb111_MASS_EV    = constant(103289138088.5563, "Sb111 mass in eV as used in FLUKA.", pdg_id=1000511110)
    Sb112_MASS_EV    = constant(104219872688.5760, "Sb112 mass in eV as used in FLUKA.", pdg_id=1000511120)
    Sb113_MASS_EV    = constant(105148545898.6491, "Sb113 mass in eV as used in FLUKA.", pdg_id=1000511130)
    Sb114_MASS_EV    = constant(106079788628.6556, "Sb114 mass in eV as used in FLUKA.", pdg_id=1000511140)
    Sb115_MASS_EV    = constant(107008957148.7159, "Sb115 mass in eV as used in FLUKA.", pdg_id=1000511150)
    Sb116_MASS_EV    = constant(107940636728.7111, "Sb116 mass in eV as used in FLUKA.", pdg_id=1000511160)
    Sb118_MASS_EV    = constant(109802446488.7416, "Sb118 mass in eV as used in FLUKA.", pdg_id=1000511180)
    Sb120_MASS_EV    = constant(111665009198.7527, "Sb120 mass in eV as used in FLUKA.", pdg_id=1000511200)

    Te112_MASS_EV    = constant(104223713694.0493, "Te112 mass in eV as used in FLUKA.", pdg_id=1000521120)
    Te113_MASS_EV    = constant(105154142934.0768, "Te113 mass in eV as used in FLUKA.", pdg_id=1000521130)
    Te114_MASS_EV    = constant(106082028254.1704, "Te114 mass in eV as used in FLUKA.", pdg_id=1000521140)
    Te115_MASS_EV    = constant(107013093064.1815, "Te115 mass in eV as used in FLUKA.", pdg_id=1000521150)
    Te116_MASS_EV    = constant(107941633804.2580, "Te116 mass in eV as used in FLUKA.", pdg_id=1000521160)
    Te117_MASS_EV    = constant(108873339094.2526, "Te117 mass in eV as used in FLUKA.", pdg_id=1000521170)
    Te118_MASS_EV    = constant(109802221414.3200, "Te118 mass in eV as used in FLUKA.", pdg_id=1000521180)
    Te119_MASS_EV    = constant(110734254164.3063, "Te119 mass in eV as used in FLUKA.", pdg_id=1000521190)
    Te120_MASS_EV    = constant(111663528464.3638, "Te120 mass in eV as used in FLUKA.", pdg_id=1000521200)
    Te121_MASS_EV    = constant(112595868964.3419, "Te121 mass in eV as used in FLUKA.", pdg_id=1000521210)
    Te122_MASS_EV    = constant(113525613084.3872, "Te122 mass in eV as used in FLUKA.", pdg_id=1000521220)

    I113_MASS_EV     = constant(105160840511.7544, "I113 mass in eV as used in FLUKA.",  pdg_id=1000531130)
    I114_MASS_EV     = constant(106090662581.7977, "I114 mass in eV as used in FLUKA.",  pdg_id=1000531140)
    I115_MASS_EV     = constant(107018549701.8912, "I115 mass in eV as used in FLUKA.",  pdg_id=1000531150)
    I116_MASS_EV     = constant(107948876511.9214, "I116 mass in eV as used in FLUKA.",  pdg_id=1000531160)
    I117_MASS_EV     = constant(108877490171.9961, "I117 mass in eV as used in FLUKA.",  pdg_id=1000531170)
    I118_MASS_EV     = constant(109808763282.0018, "I118 mass in eV as used in FLUKA.",  pdg_id=1000531180)
    I119_MASS_EV     = constant(110737265222.0793, "I119 mass in eV as used in FLUKA.",  pdg_id=1000531190)
    I120_MASS_EV     = constant(111668640882.0824, "I120 mass in eV as used in FLUKA.",  pdg_id=1000531200)
    I121_MASS_EV     = constant(112597637212.1472, "I121 mass in eV as used in FLUKA.",  pdg_id=1000531210)
    I123_MASS_EV     = constant(114458978922.1898, "I123 mass in eV as used in FLUKA.",  pdg_id=1000531230)

    Xe116_MASS_EV    = constant(107953033923.6005, "Xe116 mass in eV as used in FLUKA.", pdg_id=1000541160)
    Xe117_MASS_EV    = constant(108883433973.6289, "Xe117 mass in eV as used in FLUKA.", pdg_id=1000541170)
    Xe118_MASS_EV    = constant(109811205703.7253, "Xe118 mass in eV as used in FLUKA.", pdg_id=1000541180)
    Xe119_MASS_EV    = constant(110741764523.7496, "Xe119 mass in eV as used in FLUKA.", pdg_id=1000541190)
    Xe120_MASS_EV    = constant(111670098513.8315, "Xe120 mass in eV as used in FLUKA.", pdg_id=1000541200)
    Xe121_MASS_EV    = constant(112600867153.8503, "Xe121 mass in eV as used in FLUKA.", pdg_id=1000541210)
    Xe122_MASS_EV    = constant(113529736613.9183, "Xe122 mass in eV as used in FLUKA.", pdg_id=1000541220)
    Xe123_MASS_EV    = constant(114461152593.9203, "Xe123 mass in eV as used in FLUKA.", pdg_id=1000541230)
    Xe124_MASS_EV    = constant(115390241913.9827, "Xe124 mass in eV as used in FLUKA.", pdg_id=1000541240)
    Xe125_MASS_EV    = constant(116322204233.9706, "Xe125 mass in eV as used in FLUKA.", pdg_id=1000541250)
    Xe126_MASS_EV    = constant(117251714714.0219, "Xe126 mass in eV as used in FLUKA.", pdg_id=1000541260)
    Xe131_MASS_EV    = constant(121909945154.0023, "Xe131 mass in eV as used in FLUKA.", pdg_id=1000541310)

    Cs118_MASS_EV    = constant(109820003570.8584, "Cs118 mass in eV as used in FLUKA.", pdg_id=1000551180)
    Cs119_MASS_EV    = constant(110747590290.9597, "Cs119 mass in eV as used in FLUKA.", pdg_id=1000551190)
    Cs120_MASS_EV    = constant(111677518311.0003, "Cs120 mass in eV as used in FLUKA.", pdg_id=1000551200)
    Cs121_MASS_EV    = constant(112605765041.0844, "Cs121 mass in eV as used in FLUKA.", pdg_id=1000551210)
    Cs122_MASS_EV    = constant(113536289261.1095, "Cs122 mass in eV as used in FLUKA.", pdg_id=1000551220)
    Cs123_MASS_EV    = constant(114464850781.1856, "Cs123 mass in eV as used in FLUKA.", pdg_id=1000551230)
    Cs124_MASS_EV    = constant(115395656801.2034, "Cs124 mass in eV as used in FLUKA.", pdg_id=1000551240)
    Cs125_MASS_EV    = constant(116324794241.2645, "Cs125 mass in eV as used in FLUKA.", pdg_id=1000551250)
    Cs127_MASS_EV    = constant(118185635791.3201, "Cs127 mass in eV as used in FLUKA.", pdg_id=1000551270)
    Cs128_MASS_EV    = constant(119117444231.3120, "Cs128 mass in eV as used in FLUKA.", pdg_id=1000551280)
    Cs129_MASS_EV    = constant(120047367661.3527, "Cs129 mass in eV as used in FLUKA.", pdg_id=1000551290)
    Cs130_MASS_EV    = constant(120979465441.3371, "Cs130 mass in eV as used in FLUKA.", pdg_id=1000551300)

    Ba120_MASS_EV    = constant(111682016405.4391, "Ba120 mass in eV as used in FLUKA.", pdg_id=1000561200)
    Ba121_MASS_EV    = constant(112612077825.4762, "Ba121 mass in eV as used in FLUKA.", pdg_id=1000561210)
    Ba122_MASS_EV    = constant(113539629775.5784, "Ba122 mass in eV as used in FLUKA.", pdg_id=1000561220)
    Ba123_MASS_EV    = constant(114469810095.6125, "Ba123 mass in eV as used in FLUKA.", pdg_id=1000561230)
    Ba124_MASS_EV    = constant(115397801405.7032, "Ba124 mass in eV as used in FLUKA.", pdg_id=1000561240)
    Ba125_MASS_EV    = constant(116328852305.7147, "Ba125 mass in eV as used in FLUKA.", pdg_id=1000561250)
    Ba126_MASS_EV    = constant(117257209035.7960, "Ba126 mass in eV as used in FLUKA.", pdg_id=1000561260)
    Ba127_MASS_EV    = constant(118188583965.7991, "Ba127 mass in eV as used in FLUKA.", pdg_id=1000561270)
    Ba128_MASS_EV    = constant(119117463585.8669, "Ba128 mass in eV as used in FLUKA.", pdg_id=1000561280)
    Ba129_MASS_EV    = constant(120049299105.8580, "Ba129 mass in eV as used in FLUKA.", pdg_id=1000561290)
    Ba131_MASS_EV    = constant(121910662885.9002, "Ba131 mass in eV as used in FLUKA.", pdg_id=1000561310)

    La121_MASS_EV    = constant(112619509388.6356, "La121 mass in eV as used in FLUKA.", pdg_id=1000571210)
    La122_MASS_EV    = constant(113548861818.6911, "La122 mass in eV as used in FLUKA.", pdg_id=1000571220)
    La123_MASS_EV    = constant(114476192228.7990, "La123 mass in eV as used in FLUKA.", pdg_id=1000571230)
    La124_MASS_EV    = constant(115406093648.8403, "La124 mass in eV as used in FLUKA.", pdg_id=1000571240)
    La125_MASS_EV    = constant(116333993078.9335, "La125 mass in eV as used in FLUKA.", pdg_id=1000571250)
    La126_MASS_EV    = constant(117264276388.9648, "La126 mass in eV as used in FLUKA.", pdg_id=1000571260)
    La127_MASS_EV    = constant(118192780789.0423, "La127 mass in eV as used in FLUKA.", pdg_id=1000571270)
    La128_MASS_EV    = constant(119123611889.0595, "La128 mass in eV as used in FLUKA.", pdg_id=1000571280)
    La129_MASS_EV    = constant(120052517399.1266, "La129 mass in eV as used in FLUKA.", pdg_id=1000571290)
    La130_MASS_EV    = constant(120983686769.1350, "La130 mass in eV as used in FLUKA.", pdg_id=1000571300)
    La131_MASS_EV    = constant(121913121279.1884, "La131 mass in eV as used in FLUKA.", pdg_id=1000571310)
    La132_MASS_EV    = constant(122844617259.1884, "La132 mass in eV as used in FLUKA.", pdg_id=1000571320)
    La133_MASS_EV    = constant(123774515009.2297, "La133 mass in eV as used in FLUKA.", pdg_id=1000571330)
    La134_MASS_EV    = constant(124706096119.2275, "La134 mass in eV as used in FLUKA.", pdg_id=1000571340)

    Ce124_MASS_EV    = constant(115411171912.4421, "Ce124 mass in eV as used in FLUKA.", pdg_id=1000581240)
    Ce126_MASS_EV    = constant(117268180752.5970, "Ce126 mass in eV as used in FLUKA.", pdg_id=1000581260)
    Ce127_MASS_EV    = constant(118198417172.6297, "Ce127 mass in eV as used in FLUKA.", pdg_id=1000581270)
    Ce128_MASS_EV    = constant(119126297592.7233, "Ce128 mass in eV as used in FLUKA.", pdg_id=1000581280)
    Ce129_MASS_EV    = constant(120057066012.7421, "Ce129 mass in eV as used in FLUKA.", pdg_id=1000581290)
    Ce130_MASS_EV    = constant(120985392332.8242, "Ce130 mass in eV as used in FLUKA.", pdg_id=1000581300)
    Ce131_MASS_EV    = constant(121916639812.8306, "Ce131 mass in eV as used in FLUKA.", pdg_id=1000581310)
    Ce132_MASS_EV    = constant(122845399972.9014, "Ce132 mass in eV as used in FLUKA.", pdg_id=1000581320)
    Ce133_MASS_EV    = constant(123776950292.9000, "Ce133 mass in eV as used in FLUKA.", pdg_id=1000581330)
    Ce134_MASS_EV    = constant(124706094692.9609, "Ce134 mass in eV as used in FLUKA.", pdg_id=1000581340)
    Ce135_MASS_EV    = constant(125637700822.9580, "Ce135 mass in eV as used in FLUKA.", pdg_id=1000581350)
    Ce137_MASS_EV    = constant(127499414822.9910, "Ce137 mass in eV as used in FLUKA.", pdg_id=1000581370)
    Ce139_MASS_EV    = constant(129361349943.0183, "Ce139 mass in eV as used in FLUKA.", pdg_id=1000581390)

    Pr125_MASS_EV    = constant(116348465726.4607, "Pr125 mass in eV as used in FLUKA.", pdg_id=1000591250)
    Pr127_MASS_EV    = constant(118205444368.1303, "Pr127 mass in eV as used in FLUKA.", pdg_id=1000591270)
    Pr128_MASS_EV    = constant(119135046188.1794, "Pr128 mass in eV as used in FLUKA.", pdg_id=1000591280)
    Pr129_MASS_EV    = constant(120062870608.2745, "Pr129 mass in eV as used in FLUKA.", pdg_id=1000591290)
    Pr130_MASS_EV    = constant(120992986028.3102, "Pr130 mass in eV as used in FLUKA.", pdg_id=1000591300)
    Pr131_MASS_EV    = constant(121921388608.3903, "Pr131 mass in eV as used in FLUKA.", pdg_id=1000591310)
    Pr132_MASS_EV    = constant(122852006768.4130, "Pr132 mass in eV as used in FLUKA.", pdg_id=1000591320)
    Pr133_MASS_EV    = constant(123780781088.4835, "Pr133 mass in eV as used in FLUKA.", pdg_id=1000591330)
    Pr134_MASS_EV    = constant(124711800418.4958, "Pr134 mass in eV as used in FLUKA.", pdg_id=1000591340)
    Pr135_MASS_EV    = constant(125640919508.5574, "Pr135 mass in eV as used in FLUKA.", pdg_id=1000591350)
    Pr136_MASS_EV    = constant(126571954998.5693, "Pr136 mass in eV as used in FLUKA.", pdg_id=1000591360)
    Pr137_MASS_EV    = constant(127501615618.6168, "Pr137 mass in eV as used in FLUKA.", pdg_id=1000591370)
    Pr138_MASS_EV    = constant(128433175668.6151, "Pr138 mass in eV as used in FLUKA.", pdg_id=1000591380)

    Nd129_MASS_EV    = constant(120070193237.2685, "Nd129 mass in eV as used in FLUKA.", pdg_id=1000601290)
    Nd130_MASS_EV    = constant(120997514657.3766, "Nd130 mass in eV as used in FLUKA.", pdg_id=1000601300)
    Nd131_MASS_EV    = constant(121927447627.4171, "Nd131 mass in eV as used in FLUKA.", pdg_id=1000601310)
    Nd132_MASS_EV    = constant(122855231497.5132, "Nd132 mass in eV as used in FLUKA.", pdg_id=1000601320)
    Nd133_MASS_EV    = constant(123785877917.5352, "Nd133 mass in eV as used in FLUKA.", pdg_id=1000601330)
    Nd134_MASS_EV    = constant(124714069397.6208, "Nd134 mass in eV as used in FLUKA.", pdg_id=1000601340)
    Nd135_MASS_EV    = constant(125645168757.6310, "Nd135 mass in eV as used in FLUKA.", pdg_id=1000601350)
    Nd136_MASS_EV    = constant(126573665017.7087, "Nd136 mass in eV as used in FLUKA.", pdg_id=1000601360)
    Nd137_MASS_EV    = constant(127504804627.7179, "Nd137 mass in eV as used in FLUKA.", pdg_id=1000601370)
    Nd138_MASS_EV    = constant(128433774717.7833, "Nd138 mass in eV as used in FLUKA.", pdg_id=1000601380)
    Nd139_MASS_EV    = constant(129365263297.7835, "Nd139 mass in eV as used in FLUKA.", pdg_id=1000601390)
    Nd140_MASS_EV    = constant(130294322737.8466, "Nd140 mass in eV as used in FLUKA.", pdg_id=1000601400)

    Pm132_MASS_EV    = constant(122864632561.4900, "Pm132 mass in eV as used in FLUKA.", pdg_id=1000611320)
    Pm133_MASS_EV    = constant(123792372981.5872, "Pm133 mass in eV as used in FLUKA.", pdg_id=1000611330)
    Pm134_MASS_EV    = constant(124722451401.6240, "Pm134 mass in eV as used in FLUKA.", pdg_id=1000611340)
    Pm135_MASS_EV    = constant(125650685821.7085, "Pm135 mass in eV as used in FLUKA.", pdg_id=1000611350)
    Pm136_MASS_EV    = constant(126581014321.7386, "Pm136 mass in eV as used in FLUKA.", pdg_id=1000611360)
    Pm137_MASS_EV    = constant(127509883691.8067, "Pm137 mass in eV as used in FLUKA.", pdg_id=1000611370)
    Pm138_MASS_EV    = constant(128440173741.8379, "Pm138 mass in eV as used in FLUKA.", pdg_id=1000611380)
    Pm139_MASS_EV    = constant(129369284551.8996, "Pm139 mass in eV as used in FLUKA.", pdg_id=1000611390)
    Pm140_MASS_EV    = constant(130299910671.9222, "Pm140 mass in eV as used in FLUKA.", pdg_id=1000611400)
    Pm141_MASS_EV    = constant(131229306121.9765, "Pm141 mass in eV as used in FLUKA.", pdg_id=1000611410)
    Pm145_MASS_EV    = constant(134954492581.9971, "Pm145 mass in eV as used in FLUKA.", pdg_id=1000611450)

    Sm134_MASS_EV    = constant(124727371702.2735, "Sm134 mass in eV as used in FLUKA.", pdg_id=1000621340)
    Sm136_MASS_EV    = constant(126585032532.4116, "Sm136 mass in eV as used in FLUKA.", pdg_id=1000621360)
    Sm137_MASS_EV    = constant(127515436962.4398, "Sm137 mass in eV as used in FLUKA.", pdg_id=1000621370)
    Sm138_MASS_EV    = constant(128443587382.5265, "Sm138 mass in eV as used in FLUKA.", pdg_id=1000621380)
    Sm139_MASS_EV    = constant(129374244092.5482, "Sm139 mass in eV as used in FLUKA.", pdg_id=1000621390)
    Sm140_MASS_EV    = constant(130302430122.6339, "Sm140 mass in eV as used in FLUKA.", pdg_id=1000621400)
    Sm141_MASS_EV    = constant(131233348732.6488, "Sm141 mass in eV as used in FLUKA.", pdg_id=1000621410)
    Sm142_MASS_EV    = constant(132161799752.7277, "Sm142 mass in eV as used in FLUKA.", pdg_id=1000621420)
    Sm143_MASS_EV    = constant(133092754442.7417, "Sm143 mass in eV as used in FLUKA.", pdg_id=1000621430)
    Sm144_MASS_EV    = constant(134021800272.8051, "Sm144 mass in eV as used in FLUKA.", pdg_id=1000621440)
    Sm145_MASS_EV    = constant(134954608792.7711, "Sm145 mass in eV as used in FLUKA.", pdg_id=1000621450)

    Eu137_MASS_EV    = constant(127522463501.0964, "Eu137 mass in eV as used in FLUKA.", pdg_id=1000631370)
    Eu138_MASS_EV    = constant(128452317921.1389, "Eu138 mass in eV as used in FLUKA.", pdg_id=1000631380)
    Eu139_MASS_EV    = constant(129380421341.2268, "Eu139 mass in eV as used in FLUKA.", pdg_id=1000631390)
    Eu140_MASS_EV    = constant(130310329611.2679, "Eu140 mass in eV as used in FLUKA.", pdg_id=1000631400)
    Eu141_MASS_EV    = constant(131238398471.3566, "Eu141 mass in eV as used in FLUKA.", pdg_id=1000631410)
    Eu142_MASS_EV    = constant(132168659401.3886, "Eu142 mass in eV as used in FLUKA.", pdg_id=1000631420)
    Eu143_MASS_EV    = constant(133097422581.4594, "Eu143 mass in eV as used in FLUKA.", pdg_id=1000631430)
    Eu144_MASS_EV    = constant(134027628821.4928, "Eu144 mass in eV as used in FLUKA.", pdg_id=1000631440)
    Eu145_MASS_EV    = constant(134956768711.5538, "Eu145 mass in eV as used in FLUKA.", pdg_id=1000631450)
    Eu146_MASS_EV    = constant(135889136711.5311, "Eu146 mass in eV as used in FLUKA.", pdg_id=1000631460)
    Eu147_MASS_EV    = constant(136820203771.5423, "Eu147 mass in eV as used in FLUKA.", pdg_id=1000631470)
    Eu148_MASS_EV    = constant(137753013801.5081, "Eu148 mass in eV as used in FLUKA.", pdg_id=1000631480)

    Gd139_MASS_EV    = constant(129387625219.4307, "Gd139 mass in eV as used in FLUKA.", pdg_id=1000641390)
    Gd140_MASS_EV    = constant(130315289439.5299, "Gd140 mass in eV as used in FLUKA.", pdg_id=1000641400)
    Gd141_MASS_EV    = constant(131245146059.5724, "Gd141 mass in eV as used in FLUKA.", pdg_id=1000641410)
    Gd142_MASS_EV    = constant(132172659369.6755, "Gd142 mass in eV as used in FLUKA.", pdg_id=1000641420)
    Gd143_MASS_EV    = constant(133102929979.7073, "Gd143 mass in eV as used in FLUKA.", pdg_id=1000641430)
    Gd144_MASS_EV    = constant(134030868119.7994, "Gd144 mass in eV as used in FLUKA.", pdg_id=1000641440)
    Gd145_MASS_EV    = constant(134961323109.8263, "Gd145 mass in eV as used in FLUKA.", pdg_id=1000641450)
    Gd146_MASS_EV    = constant(135889666909.9080, "Gd146 mass in eV as used in FLUKA.", pdg_id=1000641460)
    Gd147_MASS_EV    = constant(136821891539.8890, "Gd147 mass in eV as used in FLUKA.", pdg_id=1000641470)
    Gd148_MASS_EV    = constant(137752473359.9127, "Gd148 mass in eV as used in FLUKA.", pdg_id=1000641480)
    Gd149_MASS_EV    = constant(138685112069.8830, "Gd149 mass in eV as used in FLUKA.", pdg_id=1000641490)
    Gd150_MASS_EV    = constant(139615969869.8995, "Gd150 mass in eV as used in FLUKA.", pdg_id=1000641500)
    Gd155_MASS_EV    = constant(144277132539.8039, "Gd155 mass in eV as used in FLUKA.", pdg_id=1000641550)

    Tb143_MASS_EV    = constant(133109823818.9469, "Tb143 mass in eV as used in FLUKA.", pdg_id=1000651430)
    Tb144_MASS_EV    = constant(134039287238.9995, "Tb144 mass in eV as used in FLUKA.", pdg_id=1000651440)
    Tb145_MASS_EV    = constant(134967331349.0889, "Tb145 mass in eV as used in FLUKA.", pdg_id=1000651450)
    Tb146_MASS_EV    = constant(135897242169.1300, "Tb146 mass in eV as used in FLUKA.", pdg_id=1000651460)
    Tb147_MASS_EV    = constant(136826003189.2008, "Tb147 mass in eV as used in FLUKA.", pdg_id=1000651470)
    Tb148_MASS_EV    = constant(137757666589.1964, "Tb148 mass in eV as used in FLUKA.", pdg_id=1000651480)
    Tb149_MASS_EV    = constant(138688248389.2201, "Tb149 mass in eV as used in FLUKA.", pdg_id=1000651490)
    Tb150_MASS_EV    = constant(139620126479.2101, "Tb150 mass in eV as used in FLUKA.", pdg_id=1000651500)
    Tb155_MASS_EV    = constant(144277454249.2138, "Tb155 mass in eV as used in FLUKA.", pdg_id=1000651550)

    Dy143_MASS_EV    = constant(133118089180.6405, "Dy143 mass in eV as used in FLUKA.", pdg_id=1000661430)
    Dy146_MASS_EV    = constant(135901902630.9170, "Dy146 mass in eV as used in FLUKA.", pdg_id=1000661460)
    Dy147_MASS_EV    = constant(136831876210.9564, "Dy147 mass in eV as used in FLUKA.", pdg_id=1000661470)
    Dy148_MASS_EV    = constant(137759845151.0478, "Dy148 mass in eV as used in FLUKA.", pdg_id=1000661480)
    Dy149_MASS_EV    = constant(138691560891.0420, "Dy149 mass in eV as used in FLUKA.", pdg_id=1000661490)
    Dy150_MASS_EV    = constant(139621420871.0844, "Dy150 mass in eV as used in FLUKA.", pdg_id=1000661500)
    Dy151_MASS_EV    = constant(140553473901.0699, "Dy151 mass in eV as used in FLUKA.", pdg_id=1000661510)
    Dy152_MASS_EV    = constant(141483603001.1053, "Dy152 mass in eV as used in FLUKA.", pdg_id=1000661520)
    Dy153_MASS_EV    = constant(142416073431.0800, "Dy153 mass in eV as used in FLUKA.", pdg_id=1000661530)
    Dy154_MASS_EV    = constant(143346319311.1123, "Dy154 mass in eV as used in FLUKA.", pdg_id=1000661540)
    Dy156_MASS_EV    = constant(145209173471.1158, "Dy156 mass in eV as used in FLUKA.", pdg_id=1000661560)

    Ho147_MASS_EV    = constant(136839525266.6038, "Ho147 mass in eV as used in FLUKA.", pdg_id=1000671470)
    Ho148_MASS_EV    = constant(137768745716.6627, "Ho148 mass in eV as used in FLUKA.", pdg_id=1000671480)
    Ho149_MASS_EV    = constant(138697075286.7448, "Ho149 mass in eV as used in FLUKA.", pdg_id=1000671490)
    Ho150_MASS_EV    = constant(139628161526.7553, "Ho150 mass in eV as used in FLUKA.", pdg_id=1000671500)
    Ho151_MASS_EV    = constant(140558102336.7956, "Ho151 mass in eV as used in FLUKA.", pdg_id=1000671510)
    Ho152_MASS_EV    = constant(141489577436.7961, "Ho152 mass in eV as used in FLUKA.", pdg_id=1000671520)
    Ho153_MASS_EV    = constant(142419702816.8316, "Ho153 mass in eV as used in FLUKA.", pdg_id=1000671530)
    Ho154_MASS_EV    = constant(143351571416.8219, "Ho154 mass in eV as used in FLUKA.", pdg_id=1000671540)
    Ho155_MASS_EV    = constant(144281651906.8585, "Ho155 mass in eV as used in FLUKA.", pdg_id=1000671550)
    Ho157_MASS_EV    = constant(146143810516.8800, "Ho157 mass in eV as used in FLUKA.", pdg_id=1000671570)
    Ho159_MASS_EV    = constant(148006352366.8915, "Ho159 mass in eV as used in FLUKA.", pdg_id=1000671590)

    Er149_MASS_EV    = constant(138704309787.7756, "Er149 mass in eV as used in FLUKA.", pdg_id=1000681490)
    Er150_MASS_EV    = constant(139631770477.8801, "Er150 mass in eV as used in FLUKA.", pdg_id=1000681500)
    Er151_MASS_EV    = constant(140562823597.8915, "Er151 mass in eV as used in FLUKA.", pdg_id=1000681510)
    Er152_MASS_EV    = constant(141492183387.9469, "Er152 mass in eV as used in FLUKA.", pdg_id=1000681520)
    Er153_MASS_EV    = constant(142423767427.9445, "Er153 mass in eV as used in FLUKA.", pdg_id=1000681530)
    Er154_MASS_EV    = constant(143353104298.0004, "Er154 mass in eV as used in FLUKA.", pdg_id=1000681540)
    Er155_MASS_EV    = constant(144284996327.9901, "Er155 mass in eV as used in FLUKA.", pdg_id=1000681550)
    Er156_MASS_EV    = constant(145214605248.0390, "Er156 mass in eV as used in FLUKA.", pdg_id=1000681560)
    Er157_MASS_EV    = constant(146146781428.0213, "Er157 mass in eV as used in FLUKA.", pdg_id=1000681570)
    Er159_MASS_EV    = constant(148008621808.0511, "Er159 mass in eV as used in FLUKA.", pdg_id=1000681590)
    Er162_MASS_EV    = constant(150801329878.0970, "Er162 mass in eV as used in FLUKA.", pdg_id=1000681620)

    Tm151_MASS_EV    = constant(140569854735.7222, "Tm151 mass in eV as used in FLUKA.", pdg_id=1000691510)
    Tm152_MASS_EV    = constant(141500349115.7481, "Tm152 mass in eV as used in FLUKA.", pdg_id=1000691520)
    Tm153_MASS_EV    = constant(142429727715.8029, "Tm153 mass in eV as used in FLUKA.", pdg_id=1000691530)
    Tm154_MASS_EV    = constant(143360658945.8175, "Tm154 mass in eV as used in FLUKA.", pdg_id=1000691540)
    Tm155_MASS_EV    = constant(144290075955.8713, "Tm155 mass in eV as used in FLUKA.", pdg_id=1000691550)
    Tm156_MASS_EV    = constant(145221325335.8777, "Tm156 mass in eV as used in FLUKA.", pdg_id=1000691560)
    Tm157_MASS_EV    = constant(146150762705.9309, "Tm157 mass in eV as used in FLUKA.", pdg_id=1000691570)
    Tm158_MASS_EV    = constant(147082449195.9260, "Tm158 mass in eV as used in FLUKA.", pdg_id=1000691580)
    Tm159_MASS_EV    = constant(148011973045.9770, "Tm159 mass in eV as used in FLUKA.", pdg_id=1000691590)
    Tm160_MASS_EV    = constant(148944015565.9629, "Tm160 mass in eV as used in FLUKA.", pdg_id=1000691600)
    Tm161_MASS_EV    = constant(149873643106.0112, "Tm161 mass in eV as used in FLUKA.", pdg_id=1000691610)
    Tm162_MASS_EV    = constant(150805640475.9982, "Tm162 mass in eV as used in FLUKA.", pdg_id=1000691620)

    Yb154_MASS_EV    = constant(143364649401.9305, "Yb154 mass in eV as used in FLUKA.", pdg_id=1000701540)
    Yb155_MASS_EV    = constant(144295565521.9455, "Yb155 mass in eV as used in FLUKA.", pdg_id=1000701550)
    Yb156_MASS_EV    = constant(145224399712.0145, "Yb156 mass in eV as used in FLUKA.", pdg_id=1000701560)
    Yb157_MASS_EV    = constant(146155794512.0170, "Yb157 mass in eV as used in FLUKA.", pdg_id=1000701570)
    Yb158_MASS_EV    = constant(147084679682.0847, "Yb158 mass in eV as used in FLUKA.", pdg_id=1000701580)
    Yb159_MASS_EV    = constant(148016524482.0755, "Yb159 mass in eV as used in FLUKA.", pdg_id=1000701590)
    Yb160_MASS_EV    = constant(148945527222.1401, "Yb160 mass in eV as used in FLUKA.", pdg_id=1000701600)
    Yb161_MASS_EV    = constant(149877294522.1331, "Yb161 mass in eV as used in FLUKA.", pdg_id=1000701610)
    Yb162_MASS_EV    = constant(150806829852.1838, "Yb162 mass in eV as used in FLUKA.", pdg_id=1000701620)
    Yb163_MASS_EV    = constant(151738804172.1714, "Yb163 mass in eV as used in FLUKA.", pdg_id=1000701630)
    Yb164_MASS_EV    = constant(152668672602.2135, "Yb164 mass in eV as used in FLUKA.", pdg_id=1000701640)
    Yb165_MASS_EV    = constant(153600984502.1924, "Yb165 mass in eV as used in FLUKA.", pdg_id=1000701650)
    Yb166_MASS_EV    = constant(154531064762.2289, "Yb166 mass in eV as used in FLUKA.", pdg_id=1000701660)
    Yb173_MASS_EV    = constant(161055555752.1245, "Yb173 mass in eV as used in FLUKA.", pdg_id=1000701730)

    Lu156_MASS_EV    = constant(145233347537.5995, "Lu156 mass in eV as used in FLUKA.", pdg_id=1000711560)
    Lu159_MASS_EV    = constant(148022014047.7503, "Lu159 mass in eV as used in FLUKA.", pdg_id=1000711590)
    Lu160_MASS_EV    = constant(148952908887.7658, "Lu160 mass in eV as used in FLUKA.", pdg_id=1000711600)
    Lu161_MASS_EV    = constant(149882096197.8256, "Lu161 mass in eV as used in FLUKA.", pdg_id=1000711610)
    Lu162_MASS_EV    = constant(150813551527.8266, "Lu162 mass in eV as used in FLUKA.", pdg_id=1000711620)
    Lu163_MASS_EV    = constant(151742905857.8821, "Lu163 mass in eV as used in FLUKA.", pdg_id=1000711630)
    Lu164_MASS_EV    = constant(152674424257.8814, "Lu164 mass in eV as used in FLUKA.", pdg_id=1000711640)
    Lu165_MASS_EV    = constant(153604406137.9206, "Lu165 mass in eV as used in FLUKA.", pdg_id=1000711650)

    Hf161_MASS_EV    = constant(149887922014.4767, "Hf161 mass in eV as used in FLUKA.", pdg_id=1000721610)
    Hf162_MASS_EV    = constant(150816502594.5522, "Hf162 mass in eV as used in FLUKA.", pdg_id=1000721620)
    Hf163_MASS_EV    = constant(151747857704.5558, "Hf163 mass in eV as used in FLUKA.", pdg_id=1000721630)
    Hf164_MASS_EV    = constant(152676900144.6193, "Hf164 mass in eV as used in FLUKA.", pdg_id=1000721640)
    Hf165_MASS_EV    = constant(153608503294.6165, "Hf165 mass in eV as used in FLUKA.", pdg_id=1000721650)
    Hf166_MASS_EV    = constant(154537864684.6718, "Hf166 mass in eV as used in FLUKA.", pdg_id=1000721660)
    Hf167_MASS_EV    = constant(155469685104.6634, "Hf167 mass in eV as used in FLUKA.", pdg_id=1000721670)
    Hf168_MASS_EV    = constant(156399344524.7109, "Hf168 mass in eV as used in FLUKA.", pdg_id=1000721680)
    Hf169_MASS_EV    = constant(157331331664.6982, "Hf169 mass in eV as used in FLUKA.", pdg_id=1000721690)
    Hf170_MASS_EV    = constant(158261420074.7346, "Hf170 mass in eV as used in FLUKA.", pdg_id=1000721700)
    Hf171_MASS_EV    = constant(159193697384.7143, "Hf171 mass in eV as used in FLUKA.", pdg_id=1000721710)

    Ta159_MASS_EV    = constant(148036183583.3451, "Ta159 mass in eV as used in FLUKA.", pdg_id=1000731590)
    Ta162_MASS_EV    = constant(150825267773.4850, "Ta162 mass in eV as used in FLUKA.", pdg_id=1000731620)
    Ta164_MASS_EV    = constant(152684923143.5714, "Ta164 mass in eV as used in FLUKA.", pdg_id=1000731640)
    Ta165_MASS_EV    = constant(153613853643.6379, "Ta165 mass in eV as used in FLUKA.", pdg_id=1000731650)
    Ta166_MASS_EV    = constant(154545023883.6462, "Ta166 mass in eV as used in FLUKA.", pdg_id=1000731660)
    Ta167_MASS_EV    = constant(155474191063.7066, "Ta167 mass in eV as used in FLUKA.", pdg_id=1000731670)
    Ta168_MASS_EV    = constant(156405516453.7109, "Ta168 mass in eV as used in FLUKA.", pdg_id=1000731680)
    Ta169_MASS_EV    = constant(157335268933.7561, "Ta169 mass in eV as used in FLUKA.", pdg_id=1000731690)
    Ta170_MASS_EV    = constant(158266921263.7520, "Ta170 mass in eV as used in FLUKA.", pdg_id=1000731700)
    Ta171_MASS_EV    = constant(159196897573.7913, "Ta171 mass in eV as used in FLUKA.", pdg_id=1000731710)
    Ta172_MASS_EV    = constant(160128652783.7845, "Ta172 mass in eV as used in FLUKA.", pdg_id=1000731720)
    Ta174_MASS_EV    = constant(161991109663.7983, "Ta174 mass in eV as used in FLUKA.", pdg_id=1000731740)

    W163_MASS_EV     = constant(151761121366.2512, "W163 mass in eV as used in FLUKA.",  pdg_id=1000741630)
    W165_MASS_EV     = constant(153620360626.3483, "W165 mass in eV as used in FLUKA.",  pdg_id=1000741650)
    W166_MASS_EV     = constant(154548765926.4284, "W166 mass in eV as used in FLUKA.",  pdg_id=1000741660)
    W167_MASS_EV     = constant(155479933636.4369, "W167 mass in eV as used in FLUKA.",  pdg_id=1000741670)
    W168_MASS_EV     = constant(156408813076.5046, "W168 mass in eV as used in FLUKA.",  pdg_id=1000741680)
    W169_MASS_EV     = constant(157340210286.5071, "W169 mass in eV as used in FLUKA.",  pdg_id=1000741690)
    W170_MASS_EV     = constant(158269402446.5667, "W170 mass in eV as used in FLUKA.",  pdg_id=1000741700)
    W171_MASS_EV     = constant(159200972956.5648, "W171 mass in eV as used in FLUKA.",  pdg_id=1000741710)
    W172_MASS_EV     = constant(160130655286.6117, "W172 mass in eV as used in FLUKA.",  pdg_id=1000741720)
    W173_MASS_EV     = constant(161062629506.5993, "W173 mass in eV as used in FLUKA.",  pdg_id=1000741730)
    W174_MASS_EV     = constant(161992465896.6423, "W174 mass in eV as used in FLUKA.",  pdg_id=1000741740)
    W175_MASS_EV     = constant(162924529326.6276, "W175 mass in eV as used in FLUKA.",  pdg_id=1000741750)
    W176_MASS_EV     = constant(163854923636.6560, "W176 mass in eV as used in FLUKA.",  pdg_id=1000741760)
    W177_MASS_EV     = constant(164787377856.6312, "W177 mass in eV as used in FLUKA.",  pdg_id=1000741770)
    W178_MASS_EV     = constant(165718153866.6498, "W178 mass in eV as used in FLUKA.",  pdg_id=1000741780)
    W182_MASS_EV     = constant(169446326326.5929, "W182 mass in eV as used in FLUKA.",  pdg_id=1000741820)

    Re169_MASS_EV    = constant(157346299104.2974, "Re169 mass in eV as used in FLUKA.", pdg_id=1000751690)
    Re170_MASS_EV    = constant(158277172214.3135, "Re170 mass in eV as used in FLUKA.", pdg_id=1000751700)
    Re171_MASS_EV    = constant(159206145604.3789, "Re171 mass in eV as used in FLUKA.", pdg_id=1000751710)
    Re172_MASS_EV    = constant(160137483954.3829, "Re172 mass in eV as used in FLUKA.", pdg_id=1000751720)
    Re173_MASS_EV    = constant(161066904134.4366, "Re173 mass in eV as used in FLUKA.", pdg_id=1000751730)
    Re174_MASS_EV    = constant(161998445494.4354, "Re174 mass in eV as used in FLUKA.", pdg_id=1000751740)
    Re176_MASS_EV    = constant(163859997344.4727, "Re176 mass in eV as used in FLUKA.", pdg_id=1000751760)
    Re177_MASS_EV    = constant(164790280664.5040, "Re177 mass in eV as used in FLUKA.", pdg_id=1000751770)
    Re178_MASS_EV    = constant(165722316564.4900, "Re178 mass in eV as used in FLUKA.", pdg_id=1000751780)
    Re179_MASS_EV    = constant(166652999954.5110, "Re179 mass in eV as used in FLUKA.", pdg_id=1000751790)
    Re180_MASS_EV    = constant(167585245594.4916, "Re180 mass in eV as used in FLUKA.", pdg_id=1000751800)
    Re181_MASS_EV    = constant(168516066334.5090, "Re181 mass in eV as used in FLUKA.", pdg_id=1000751810)
    Re182_MASS_EV    = constant(169448629054.4813, "Re182 mass in eV as used in FLUKA.", pdg_id=1000751820)
    Re183_MASS_EV    = constant(170379759904.4908, "Re183 mass in eV as used in FLUKA.", pdg_id=1000751830)
    Re187_MASS_EV    = constant(174110328834.3718, "Re187 mass in eV as used in FLUKA.", pdg_id=1000751870)
    Re192_MASS_EV    = constant(178777310464.1253, "Re192 mass in eV as used in FLUKA.", pdg_id=1000751920)

    Os172_MASS_EV    = constant(160141448038.6361, "Os172 mass in eV as used in FLUKA.", pdg_id=1000761720)
    Os173_MASS_EV    = constant(161072675238.6430, "Os173 mass in eV as used in FLUKA.", pdg_id=1000761730)
    Os174_MASS_EV    = constant(162001682398.7075, "Os174 mass in eV as used in FLUKA.", pdg_id=1000761740)
    Os175_MASS_EV    = constant(162933093888.7097, "Os175 mass in eV as used in FLUKA.", pdg_id=1000761750)
    Os176_MASS_EV    = constant(163862664308.7595, "Os176 mass in eV as used in FLUKA.", pdg_id=1000761760)
    Os177_MASS_EV    = constant(164794256548.7569, "Os177 mass in eV as used in FLUKA.", pdg_id=1000761770)
    Os178_MASS_EV    = constant(165724154328.7983, "Os178 mass in eV as used in FLUKA.", pdg_id=1000761780)
    Os179_MASS_EV    = constant(166656181228.7845, "Os179 mass in eV as used in FLUKA.", pdg_id=1000761790)
    Os180_MASS_EV    = constant(167586214608.8224, "Os180 mass in eV as used in FLUKA.", pdg_id=1000761800)
    Os181_MASS_EV    = constant(168518498888.8019, "Os181 mass in eV as used in FLUKA.", pdg_id=1000761810)
    Os182_MASS_EV    = constant(169449039998.8266, "Os182 mass in eV as used in FLUKA.", pdg_id=1000761820)
    Os183_MASS_EV    = constant(170381394648.8043, "Os183 mass in eV as used in FLUKA.", pdg_id=1000761830)
    Os184_MASS_EV    = constant(171312312238.8192, "Os184 mass in eV as used in FLUKA.", pdg_id=1000761840)

    Ir174_MASS_EV    = constant(162010204690.5783, "Ir174 mass in eV as used in FLUKA.", pdg_id=1000771740)
    Ir176_MASS_EV    = constant(163870129420.6577, "Ir176 mass in eV as used in FLUKA.", pdg_id=1000771760)
    Ir177_MASS_EV    = constant(164799439600.7144, "Ir177 mass in eV as used in FLUKA.", pdg_id=1000771770)
    Ir178_MASS_EV    = constant(165730854010.7164, "Ir178 mass in eV as used in FLUKA.", pdg_id=1000771780)
    Ir179_MASS_EV    = constant(166660546290.7631, "Ir179 mass in eV as used in FLUKA.", pdg_id=1000771790)
    Ir180_MASS_EV    = constant(167592134710.7607, "Ir180 mass in eV as used in FLUKA.", pdg_id=1000771800)
    Ir181_MASS_EV    = constant(168522071090.8010, "Ir181 mass in eV as used in FLUKA.", pdg_id=1000771810)
    Ir182_MASS_EV    = constant(169454152630.7858, "Ir182 mass in eV as used in FLUKA.", pdg_id=1000771820)
    Ir183_MASS_EV    = constant(170384347830.8195, "Ir183 mass in eV as used in FLUKA.", pdg_id=1000771830)
    Ir184_MASS_EV    = constant(171316377460.8056, "Ir184 mass in eV as used in FLUKA.", pdg_id=1000771840)
    Ir185_MASS_EV    = constant(172247128410.8249, "Ir185 mass in eV as used in FLUKA.", pdg_id=1000771850)
    Ir186_MASS_EV    = constant(173179890410.7921, "Ir186 mass in eV as used in FLUKA.", pdg_id=1000771860)
    Ir187_MASS_EV    = constant(174110834780.8063, "Ir187 mass in eV as used in FLUKA.", pdg_id=1000771870)
    Ir188_MASS_EV    = constant(175043718090.7703, "Ir188 mass in eV as used in FLUKA.", pdg_id=1000771880)
    Ir194_MASS_EV    = constant(180638481160.6201, "Ir194 mass in eV as used in FLUKA.", pdg_id=1000771940)
    Ir195_MASS_EV    = constant(181570814980.5983, "Ir195 mass in eV as used in FLUKA.", pdg_id=1000771950)

    Pt176_MASS_EV    = constant(163874743011.6830, "Pt176 mass in eV as used in FLUKA.", pdg_id=1000781760)
    Pt177_MASS_EV    = constant(164805727221.6962, "Pt177 mass in eV as used in FLUKA.", pdg_id=1000781770)
    Pt178_MASS_EV    = constant(165734665381.7625, "Pt178 mass in eV as used in FLUKA.", pdg_id=1000781780)
    Pt179_MASS_EV    = constant(166665783871.7722, "Pt179 mass in eV as used in FLUKA.", pdg_id=1000781790)
    Pt180_MASS_EV    = constant(167595330291.8227, "Pt180 mass in eV as used in FLUKA.", pdg_id=1000781800)
    Pt181_MASS_EV    = constant(168526798541.8233, "Pt181 mass in eV as used in FLUKA.", pdg_id=1000781810)
    Pt182_MASS_EV    = constant(169456505811.8696, "Pt182 mass in eV as used in FLUKA.", pdg_id=1000781820)
    Pt183_MASS_EV    = constant(170388429221.8585, "Pt183 mass in eV as used in FLUKA.", pdg_id=1000781830)
    Pt184_MASS_EV    = constant(171318213591.9028, "Pt184 mass in eV as used in FLUKA.", pdg_id=1000781840)
    Pt185_MASS_EV    = constant(172250449861.8836, "Pt185 mass in eV as used in FLUKA.", pdg_id=1000781850)
    Pt186_MASS_EV    = constant(173180772881.9140, "Pt186 mass in eV as used in FLUKA.", pdg_id=1000781860)
    Pt187_MASS_EV    = constant(174113446571.8834, "Pt187 mass in eV as used in FLUKA.", pdg_id=1000781870)
    Pt188_MASS_EV    = constant(175043728091.9148, "Pt188 mass in eV as used in FLUKA.", pdg_id=1000781880)
    Pt189_MASS_EV    = constant(175976560161.8802, "Pt189 mass in eV as used in FLUKA.", pdg_id=1000781890)
    Pt190_MASS_EV    = constant(176907214431.9019, "Pt190 mass in eV as used in FLUKA.", pdg_id=1000781900)
    Pt196_MASS_EV    = constant(182500842081.7811, "Pt196 mass in eV as used in FLUKA.", pdg_id=1000781960)
    Pt197_MASS_EV    = constant(183434561301.7235, "Pt197 mass in eV as used in FLUKA.", pdg_id=1000781970)
    Pt198_MASS_EV    = constant(184366570411.7101, "Pt198 mass in eV as used in FLUKA.", pdg_id=1000781980)

    Au181_MASS_EV    = constant(168532601103.1779, "Au181 mass in eV as used in FLUKA.", pdg_id=1000791810)
    Au182_MASS_EV    = constant(169463789513.1858, "Au182 mass in eV as used in FLUKA.", pdg_id=1000791820)
    Au183_MASS_EV    = constant(170393421793.2340, "Au183 mass in eV as used in FLUKA.", pdg_id=1000791830)
    Au184_MASS_EV    = constant(171324844213.2360, "Au184 mass in eV as used in FLUKA.", pdg_id=1000791840)
    Au185_MASS_EV    = constant(172254660603.2794, "Au185 mass in eV as used in FLUKA.", pdg_id=1000791850)
    Au186_MASS_EV    = constant(173186317243.2752, "Au186 mass in eV as used in FLUKA.", pdg_id=1000791860)
    Au187_MASS_EV    = constant(174116550323.3079, "Au187 mass in eV as used in FLUKA.", pdg_id=1000791870)
    Au188_MASS_EV    = constant(175048531693.2953, "Au188 mass in eV as used in FLUKA.", pdg_id=1000791880)
    Au189_MASS_EV    = constant(175978913913.3241, "Au189 mass in eV as used in FLUKA.", pdg_id=1000791890)
    Au190_MASS_EV    = constant(176911160213.3046, "Au190 mass in eV as used in FLUKA.", pdg_id=1000791900)
    Au191_MASS_EV    = constant(177841676903.3299, "Au191 mass in eV as used in FLUKA.", pdg_id=1000791910)
    Au192_MASS_EV    = constant(178774252453.3019, "Au192 mass in eV as used in FLUKA.", pdg_id=1000791920)
    Au193_MASS_EV    = constant(179705114703.3183, "Au193 mass in eV as used in FLUKA.", pdg_id=1000791930)
    Au194_MASS_EV    = constant(180637733603.2891, "Au194 mass in eV as used in FLUKA.", pdg_id=1000791940)
    Au195_MASS_EV    = constant(181568928903.2969, "Au195 mass in eV as used in FLUKA.", pdg_id=1000791950)
    Au197_MASS_EV    = constant(183433346143.2599, "Au197 mass in eV as used in FLUKA.", pdg_id=1000791970)
    Au198_MASS_EV    = constant(184366399563.2195, "Au198 mass in eV as used in FLUKA.", pdg_id=1000791980)

    Hg180_MASS_EV    = constant(167608411036.1504, "Hg180 mass in eV as used in FLUKA.", pdg_id=1000801800)
    Hg185_MASS_EV    = constant(172259986556.3031, "Hg185 mass in eV as used in FLUKA.", pdg_id=1000801850)
    Hg186_MASS_EV    = constant(173189121536.3642, "Hg186 mass in eV as used in FLUKA.", pdg_id=1000801860)
    Hg187_MASS_EV    = constant(174120919236.3564, "Hg187 mass in eV as used in FLUKA.", pdg_id=1000801870)
    Hg188_MASS_EV    = constant(175050333616.4103, "Hg188 mass in eV as used in FLUKA.", pdg_id=1000801880)
    Hg189_MASS_EV    = constant(175982367836.3963, "Hg189 mass in eV as used in FLUKA.", pdg_id=1000801890)
    Hg190_MASS_EV    = constant(176912138286.4409, "Hg190 mass in eV as used in FLUKA.", pdg_id=1000801900)
    Hg191_MASS_EV    = constant(177844360866.4221, "Hg191 mass in eV as used in FLUKA.", pdg_id=1000801910)
    Hg192_MASS_EV    = constant(178774467356.4581, "Hg192 mass in eV as used in FLUKA.", pdg_id=1000801920)
    Hg193_MASS_EV    = constant(179706959076.4323, "Hg193 mass in eV as used in FLUKA.", pdg_id=1000801930)
    Hg194_MASS_EV    = constant(180637277596.4627, "Hg194 mass in eV as used in FLUKA.", pdg_id=1000801940)
    Hg195_MASS_EV    = constant(181569942886.4324, "Hg195 mass in eV as used in FLUKA.", pdg_id=1000801950)
    Hg196_MASS_EV    = constant(182500669716.4522, "Hg196 mass in eV as used in FLUKA.", pdg_id=1000801960)
    Hg197_MASS_EV    = constant(183433449936.4189, "Hg197 mass in eV as used in FLUKA.", pdg_id=1000801970)
    Hg198_MASS_EV    = constant(184364531166.4296, "Hg198 mass in eV as used in FLUKA.", pdg_id=1000801980)
    Hg199_MASS_EV    = constant(185297432786.3932, "Hg199 mass in eV as used in FLUKA.", pdg_id=1000801990)
    Hg200_MASS_EV    = constant(186228970206.3921, "Hg200 mass in eV as used in FLUKA.", pdg_id=1000802000)
    Hg202_MASS_EV    = constant(188094116946.3361, "Hg202 mass in eV as used in FLUKA.", pdg_id=1000802020)
    Hg204_MASS_EV    = constant(189959760386.2673, "Hg204 mass in eV as used in FLUKA.", pdg_id=1000802040)
    Hg206_MASS_EV    = constant(191826497036.1702, "Hg206 mass in eV as used in FLUKA.", pdg_id=1000802060)

    Tl188_MASS_EV    = constant(175057632842.3265, "Tl188 mass in eV as used in FLUKA.", pdg_id=1000811880)
    Tl189_MASS_EV    = constant(175987048032.3804, "Tl189 mass in eV as used in FLUKA.", pdg_id=1000811890)
    Tl190_MASS_EV    = constant(176918642272.3778, "Tl190 mass in eV as used in FLUKA.", pdg_id=1000811900)
    Tl191_MASS_EV    = constant(177848357802.4239, "Tl191 mass in eV as used in FLUKA.", pdg_id=1000811910)
    Tl192_MASS_EV    = constant(178780091652.4177, "Tl192 mass in eV as used in FLUKA.", pdg_id=1000811920)
    Tl193_MASS_EV    = constant(179710102492.4562, "Tl193 mass in eV as used in FLUKA.", pdg_id=1000811930)
    Tl195_MASS_EV    = constant(181572249202.4779, "Tl195 mass in eV as used in FLUKA.", pdg_id=1000811950)
    Tl196_MASS_EV    = constant(182504550492.4570, "Tl196 mass in eV as used in FLUKA.", pdg_id=1000811960)
    Tl197_MASS_EV    = constant(183435137012.4806, "Tl197 mass in eV as used in FLUKA.", pdg_id=1000811970)
    Tl198_MASS_EV    = constant(184367495382.4582, "Tl198 mass in eV as used in FLUKA.", pdg_id=1000811980)
    Tl199_MASS_EV    = constant(185298381682.4739, "Tl199 mass in eV as used in FLUKA.", pdg_id=1000811990)
    Tl200_MASS_EV    = constant(186230930442.4466, "Tl200 mass in eV as used in FLUKA.", pdg_id=1000812000)
    Tl201_MASS_EV    = constant(187162292702.4500, "Tl201 mass in eV as used in FLUKA.", pdg_id=1000812010)
    Tl202_MASS_EV    = constant(188094985622.4189, "Tl202 mass in eV as used in FLUKA.", pdg_id=1000812020)
    Tl203_MASS_EV    = constant(189026702132.4132, "Tl203 mass in eV as used in FLUKA.", pdg_id=1000812030)
    Tl204_MASS_EV    = constant(189959611952.3765, "Tl204 mass in eV as used in FLUKA.", pdg_id=1000812040)
    Tl205_MASS_EV    = constant(190891631172.3629, "Tl205 mass in eV as used in FLUKA.", pdg_id=1000812050)
    Tl206_MASS_EV    = constant(191824693192.3223, "Tl206 mass in eV as used in FLUKA.", pdg_id=1000812060)
    Tl207_MASS_EV    = constant(192757410582.2906, "Tl207 mass in eV as used in FLUKA.", pdg_id=1000812070)

    Pb192_MASS_EV    = constant(178782965692.6692, "Pb192 mass in eV as used in FLUKA.", pdg_id=1000821920)
    Pb193_MASS_EV    = constant(179714758002.6615, "Pb193 mass in eV as used in FLUKA.", pdg_id=1000821930)
    Pb194_MASS_EV    = constant(180644286362.7124, "Pb194 mass in eV as used in FLUKA.", pdg_id=1000821940)
    Pb196_MASS_EV    = constant(182506100752.7429, "Pb196 mass in eV as used in FLUKA.", pdg_id=1000821960)
    Pb197_MASS_EV    = constant(183438220372.7266, "Pb197 mass in eV as used in FLUKA.", pdg_id=1000821970)
    Pb198_MASS_EV    = constant(184368409862.7605, "Pb198 mass in eV as used in FLUKA.", pdg_id=1000821980)
    Pb199_MASS_EV    = constant(185300769542.7380, "Pb199 mass in eV as used in FLUKA.", pdg_id=1000821990)
    Pb200_MASS_EV    = constant(186231245422.7644, "Pb200 mass in eV as used in FLUKA.", pdg_id=1000822000)
    Pb201_MASS_EV    = constant(187163700122.7396, "Pb201 mass in eV as used in FLUKA.", pdg_id=1000822010)
    Pb202_MASS_EV    = constant(188094539772.7565, "Pb202 mass in eV as used in FLUKA.", pdg_id=1000822020)
    Pb203_MASS_EV    = constant(189027181622.7268, "Pb203 mass in eV as used in FLUKA.", pdg_id=1000822030)
    Pb204_MASS_EV    = constant(189958352782.7352, "Pb204 mass in eV as used in FLUKA.", pdg_id=1000822040)
    Pb205_MASS_EV    = constant(190891186902.7004, "Pb205 mass in eV as used in FLUKA.", pdg_id=1000822050)
    Pb206_MASS_EV    = constant(191822664522.7009, "Pb206 mass in eV as used in FLUKA.", pdg_id=1000822060)
    Pb207_MASS_EV    = constant(192755492342.6663, "Pb207 mass in eV as used in FLUKA.", pdg_id=1000822070)
    Pb208_MASS_EV    = constant(193687690162.6481, "Pb208 mass in eV as used in FLUKA.", pdg_id=1000822080)

    Bi197_MASS_EV    = constant(183442901148.4195, "Bi197 mass in eV as used in FLUKA.", pdg_id=1000831970)
